/*******************************************************************************
 * Copyright (c) 2009 Martin O. J. Schmitz.
 * 
 * This file is part of the SCHMITZM library - a collection of utility 
 * classes based on Java 1.6, focusing (not only) on Java Swing 
 * and the Geotools library.
 * 
 * The SCHMITZM project is hosted at:
 * http://wald.intevation.org/projects/schmitzm/
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 3
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License (license.txt)
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 * or try this link: http://www.gnu.org/licenses/lgpl.html
 * 
 * Contributors:
 *     Martin O. J. Schmitz - initial API and implementation
 *     Stefan A. Krüger - additional utility classes
 ******************************************************************************/
package appl.data;

import schmitzm.data.WritableGrid;

/**
 * Defines the base functionality of late loading. Late loading means that the
 * data is loaded into memory only when it is accessed (for example by
 * <code>getRasterSample(..)</code>-Methods when implemented for
 * {@link WritableGrid}s). Notice that this class can be used with any datatype
 * (not only grids).
 * 
 * @author Dominik Appl
 */
public interface LateLoadable {
	/**
	 * Answers if the data type supports late loading
	 * 
	 * @return true, if late loading is supported
	 */
	public boolean isLateLoadable();

	/**
	 * Loads the Data into the memory if this function supported. Else it should
	 * be already loaded
	 * 
	 * @throws LoadingException
	 *             if the loading fails
	 */
	public void loadData() throws LoadingException;

	/**
	 * Unloads the Data onto disk or into nirvana, depending on implementation.
	 * Or does nothing, if late loading is not supported. <b>NOTICE</b>:
	 * UNLOADING DOES NOT MEAN, THAT DATA IS WRITTEN BACK TO THE SOURCE. It may
	 * be stored in a temporary file for later loading/export, depending on
	 * implementation.
	 */
	public void unloadData();

}
