/*******************************************************************************
 * Copyright (c) 2009 Martin O. J. Schmitz.
 * 
 * This file is part of the SCHMITZM library - a collection of utility 
 * classes based on Java 1.6, focusing (not only) on Java Swing 
 * and the Geotools library.
 * 
 * The SCHMITZM project is hosted at:
 * http://wald.intevation.org/projects/schmitzm/
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 3
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License (license.txt)
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 * or try this link: http://www.gnu.org/licenses/lgpl.html
 * 
 * Contributors:
 *     Martin O. J. Schmitz - initial API and implementation
 *     Stefan A. Krüger - additional utility classes
 ******************************************************************************/
package schmitzm.data;

import org.opengis.referencing.crs.CoordinateReferenceSystem;

/**
 * Diese Klasse bildet eine Basis-Implementierung von {@link WritableGrid}.
 * @author <a href="mailto:martin.schmitz@koeln.de">Martin Schmitz</a> (University of Bonn/Germany)
 * @version 1.0
 */
public abstract class AbstractWritableGrid extends AbstractReadableGrid implements WritableGrid {
  /**
   * Erzeugt ein AbstractWritableGrid.
   * @param crs CoordinateReferenceSystem
   */
  public AbstractWritableGrid(CoordinateReferenceSystem crs) {
    super(crs);
  }

  /**
   * Creates an abstract WritableGrid with a default CRS (WGS84)
   */
  public AbstractWritableGrid() {
    this(null);
  }

  /**
   * Liefert einen Wert des Rasters ueber Geo-Koordinaten. Liegt der
   * Koordinatenwert genau auf der Grenze zwischen zwei Rasterzellen, wird die
   * naechst groessere Zelle gewaehlt (ausser die Grenze entspricht dem Raster-Rand!).
   * @param coord  2D-Raster-Koordinate (Lat/Lon-GeoReferenz)
   * @exception UnsupportedOperationException falls zu {@linkplain #RASTER_DIM wenig}
   *            Koordinaten angegeben werden
   */
  public void setGridSample(Object value, double... coord) {
    if ( coord.length < RASTER_DIM )
      throw new UnsupportedOperationException(RASTER_DIM+" Coordinates expected");
    // Koordinaten umrechnen in Zellen-Index
    int cellX = convertRealToRaster(coord[0],0);
    int cellY = convertRealToRaster(coord[1],1);
    setRasterSample(value,cellX,cellY);
  }
}
