/*******************************************************************************
 * Copyright (c) 2009 Martin O. J. Schmitz.
 * 
 * This file is part of the SCHMITZM library - a collection of utility 
 * classes based on Java 1.6, focusing (not only) on Java Swing 
 * and the Geotools library.
 * 
 * The SCHMITZM project is hosted at:
 * http://wald.intevation.org/projects/schmitzm/
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 3
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License (license.txt)
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 * or try this link: http://www.gnu.org/licenses/lgpl.html
 * 
 * Contributors:
 *     Martin O. J. Schmitz - initial API and implementation
 *     Stefan A. Krüger - additional utility classes
 ******************************************************************************/
package schmitzm.data.event;

/**
 * Dieses Ereignis wird an die <code>ObjectListener</code> propagiert, wenn
 * sich "irgendetwas" an einem Objekt geaendert hat.
 * @see schmitzm.data.event.ObjectListener
 * @see schmitzm.data.event.ObjectEvent
 * @author <a href="mailto:martin.schmitz@koeln.de">Martin Schmitz</a> (University of Bonn/Germany)
 * @version 1.0
 */
public class ObjectChangeEvent extends AbstractObjectEvent {
  /**
   * Speichert den alten Wert bei einer Wertaenderung.
   */
  protected Object oldValue = null;

  /**
   * Speichert den neuen Wert bei einer Wertaenderung.
   */
  protected Object newValue = null;

  /**
   * Erzeugt ein neues <code>ObjectChangeEvent</code>.
   * <code>source.getRoot()<code> stellt das Objekt dar, welches sich geaendert
   * hat.<br>
   * Siehe auch Erlauterung zu <code>ObjectEvent</code>.
   * @param source   "Kette" zu veraendertem Objekt
   * @param oldValue Wert vor Veraenderung
   * @param newValue Wert nach Veraenderung
   * @see schmitzm.data.event.ObjectEvent
   */
  public ObjectChangeEvent(Invoker source, Object oldValue, Object newValue) {
    super(source,AbstractObjectEvent.STATE_CHANGED);
    this.oldValue = oldValue;
    this.newValue = newValue;
  }

  /**
   * Liefert den Wert des Objekts <u>vor</u> der Aenderung.
   */
  public Object getOldValue() {
    return this.oldValue;
  }

  /**
   * Liefert den Wert des Objekts <u>nach</u> der Aenderung.
   */
  public Object getNewValue() {
    return this.newValue;
  }

}
