/*******************************************************************************
 * Copyright (c) 2009 Martin O. J. Schmitz.
 * 
 * This file is part of the SCHMITZM library - a collection of utility 
 * classes based on Java 1.6, focusing (not only) on Java Swing 
 * and the Geotools library.
 * 
 * The SCHMITZM project is hosted at:
 * http://wald.intevation.org/projects/schmitzm/
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 3
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License (license.txt)
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 * or try this link: http://www.gnu.org/licenses/lgpl.html
 * 
 * Contributors:
 *     Martin O. J. Schmitz - initial API and implementation
 *     Stefan A. Krüger - additional utility classes
 ******************************************************************************/
package schmitzm.data.event;

/**
 * Dieses Interface muessen alle Objekte implementieren, die Aenderungen
 * "an sich selbst" an <code>ObjectListener</code> propagieren sollen.
 * Eine Aenderung kann eine Eigenschaftsmodifikation sein, oder auch die
 * "Zerstoerung" (Dispose) des Objekts. Eine weitere Moeglichkeit ist die
 * Mitgliedschaft in eine Menge. Wird ein Objekt eine Menge hinzugefuegt, oder
 * daraus entfernt, kann es dies an <code>ObjectListener</code> melden.
 * Die Art der Aenderung wird durch ein entsprechendes <code>ObjectEvent</code>
 * spezifiziert.
 * @see schmitzm.data.event.ObjectListener
 * @see schmitzm.data.event.ObjectEvent
 * @author <a href="mailto:martin.schmitz@koeln.de">Martin Schmitz</a> (University of Bonn/Germany)
 * @version 1.0
 */
public interface ObjectTraceable {
  /**
   * Fuegt dem Objekt einen Listener hinzu, der bei Aenderungen informiert wird.
   */
  public void addObjectListener(ObjectListener listener);

  /**
   * Entfernt einen Listener von dem Objekt.
   */
  public void removeObjectListener(ObjectListener listener);

//  /**
//   * Entfernt alle Listener von dem Objekt.
//   */
//  protected void removeAllObjectListeners();

  /**
   * Checkt, ob der angegebene Listener dem Objekt zugeordnet ist.
   */
  public boolean containsObjectListener(ObjectListener l);

  /**
   * Liefert alle Listener eines bestimmten Typs.
   * @param type Art des Listeners (Filter)
   */
  public ObjectListener[] getObjectListener(Class type);

  /**
   * Informiert alle Listener, dass sich das Objekt (this) geaendert hat.
   */
  public void fireEvent(ObjectEvent e);

  /**
   * Informiert alle Listener eine bestimmten Klasse, dass sich das Objekt
   * (this) geaendert hat.
   */
  public void fireEvent(ObjectEvent e, Class c);
}
