/*******************************************************************************
 * Copyright (c) 2009 Martin O. J. Schmitz.
 * 
 * This file is part of the SCHMITZM library - a collection of utility 
 * classes based on Java 1.6, focusing (not only) on Java Swing 
 * and the Geotools library.
 * 
 * The SCHMITZM project is hosted at:
 * http://wald.intevation.org/projects/schmitzm/
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 3
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License (license.txt)
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 * or try this link: http://www.gnu.org/licenses/lgpl.html
 * 
 * Contributors:
 *     Martin O. J. Schmitz - initial API and implementation
 *     Stefan A. Krüger - additional utility classes
 ******************************************************************************/
package schmitzm.data.property;

/**
 * Dieses Interface ist von allen Objektklassen zu implementieren, fuer die
 * besondere Zugriffsrechte erteilt werden sollen.
 * @see schmitzm.data.property.Access
 * @author <a href="mailto:martin.schmitz@koeln.de">Martin Schmitz</a> (University of Bonn/Germany)
 * @version 1.0
 */
public interface Accessible {
  /**
   * Wird aufgerufen, wenn ein Zugriffsrecht von einem Objekt wieder freigegen
   * wird oder das Zugriffsrecht entzogen wurde.
   * @param access erzeugtes Zugriffsrecht
   */
  public void releaseAccess(Access access);

  /**
   * Wird aufgerufen, wenn ein Zugriffsrecht fuer das Objekt erzeugt wird.
   * @param access erzeugtes Zugriffsrecht
   */
  public void applyAccess(Access access);

  /**
   * Entzieht saemtlichen Zugriffsrechten, die aktuell fuer das Objekt
   * verteilt sind, die Gueltigkeit.
   */
  public void disposeAllAccess();

  /**
   * Liefert die Anzahl an Zugriffsrechten einer bestimmten Art, die aktuell
   * fuer das Objekt verteilt sind.
   */
  public int getAccessCount(Class c);

  /**
   * Prueft, ob aktuell Zugriffsrechte einer bestimmten Art
   * auf das Objekt verteilt sind.
   */
  public boolean hasAccess(Class c);

  /**
   * Liefert die Anzahl an Zugriffsrechten, die aktuell fuer das Objekt verteilt
   * sind.
   */
  public int getAccessCount();

  /**
   * Prueft, ob aktuell Zugriffsrechte auf das Objekt verteilt sind.
   */
  public boolean hasAccess();
}
