/*******************************************************************************
 * Copyright (c) 2009 Martin O. J. Schmitz.
 * 
 * This file is part of the SCHMITZM library - a collection of utility 
 * classes based on Java 1.6, focusing (not only) on Java Swing 
 * and the Geotools library.
 * 
 * The SCHMITZM project is hosted at:
 * http://wald.intevation.org/projects/schmitzm/
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 3
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License (license.txt)
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 * or try this link: http://www.gnu.org/licenses/lgpl.html
 * 
 * Contributors:
 *     Martin O. J. Schmitz - initial API and implementation
 *     Stefan A. Krüger - additional utility classes
 ******************************************************************************/
package schmitzm.geotools.feature;

import org.opengis.feature.type.AttributeDescriptor;
import org.opengis.feature.type.GeometryDescriptor;

import schmitzm.geotools.gui.FeatureFilterPanel;

// fuer Doku

/**
 * Dieses Interface definiert einen Filter fuer die Attribute eines
 * Features oder einer FeatureCollection. Hiermit lassen sich bestimmte Attribute
 * ausblenden, so dass z.B. die Geometrie eines Features nicht in einer
 * Tabelle dargestellt wird.
 * @see FeatureTypeTableModel
 * @see FeatureFilterPanel
 * @see FeatureCollectionPane
 * @see FeatureCollectionPane.FeatureCollectionTableModel
 * @author <a href="mailto:martin.schmitz@koeln.de">Martin Schmitz</a> (University of Bonn/Germany)
 * @version 1.0
 */
public interface AttributeTypeFilter {

  /**
   * Standard-Filter, der alle Attribute akzeptiert.
   */
  public static final AttributeTypeFilter ALL = new AttributeTypeFilter() {
    public boolean accept(AttributeDescriptor type) {
      return true;
    }
  };
 
  /**
	 * Standard-Filter, der {@linkplain GeometryDescriptor
	 * Geometrie-Attribute} ausblendet.
	 */
	public static final AttributeTypeFilter NO_GEOMETRY = new AttributeTypeFilter() {
		public boolean accept(AttributeDescriptor desciptor) {
			return !(desciptor instanceof GeometryDescriptor);
		}
	};

  /**
   * Bestimmt, ob eine Attribut dargestellt wird, oder nicht.
   * @param type ein Attribut-Typ
   * @param idx  der Index des Attributs
   */
  public boolean accept(AttributeDescriptor type);
}
