/*******************************************************************************
 * Copyright (c) 2009 Martin O. J. Schmitz.
 * 
 * This file is part of the SCHMITZM library - a collection of utility 
 * classes based on Java 1.6, focusing (not only) on Java Swing 
 * and the Geotools library.
 * 
 * The SCHMITZM project is hosted at:
 * http://wald.intevation.org/projects/schmitzm/
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 3
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License (license.txt)
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 * or try this link: http://www.gnu.org/licenses/lgpl.html
 * 
 * Contributors:
 *     Martin O. J. Schmitz - initial API and implementation
 *     Stefan A. Krüger - additional utility classes
 ******************************************************************************/
package schmitzm.geotools.feature;

import org.opengis.feature.type.AttributeDescriptor;

/**
 * This interface represents a generator to create an attribute default
 * value individually.
 * @see FeatureUtil#registerAutoValueGenerator(AttributeDescriptor, AutoValueGenerator)
 * @see FeatureUtil#getAutoValueGenerator(AttributeDescriptor)
 * @author <a href="mailto:martin.schmitz@koeln.de">Martin Schmitz</a> (University of Bonn/Germany)
 */
public interface AutoValueGenerator<E> {
  /**
   * Resets the generator, so the next {@link #generateNextValue()} call
   * generates {@code firstValue} as auto value.
   * @param firstValue next value to generate (if {@code null} the
   *                   first value is reset to a previous set first
   *                   value)
   */
  public void resetAutoValue(E firstValue);

  /**
   * Returns the next value.
   */
  public E getNextValue();

}
