/*******************************************************************************
 * Copyright (c) 2009 Martin O. J. Schmitz.
 * 
 * This file is part of the SCHMITZM library - a collection of utility 
 * classes based on Java 1.6, focusing (not only) on Java Swing 
 * and the Geotools library.
 * 
 * The SCHMITZM project is hosted at:
 * http://wald.intevation.org/projects/schmitzm/
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 3
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License (license.txt)
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 * or try this link: http://www.gnu.org/licenses/lgpl.html
 * 
 * Contributors:
 *     Martin O. J. Schmitz - initial API and implementation
 *     Stefan A. Krüger - additional utility classes
 ******************************************************************************/

package schmitzm.geotools.feature;

import java.util.Iterator;

import org.geotools.feature.FeatureIterator;
import org.opengis.feature.simple.SimpleFeature;

/**
 * This class is a workaround since {@link FeatureIterator} does not
 * implement {@link Iterator}.
 * This class simply pipes all function calls to the {@link FeatureIterator}
 * specified in the constructor, but can be used with the Java standard
 * {@link Iterator} interface.
 * @author <a href="mailto:martin.schmitz@koeln.de">Martin Schmitz</a>
 *
 */
public class PipedFeatureIterator implements Iterator<SimpleFeature> {
  /** Holds the {@link FeatureIterator} which is piped. */
  protected FeatureIterator<SimpleFeature> iterator = null;
  
  /**
   * Creates a new iterator.
   * @param iterator {@link FeatureIterator} which is piped
   */
  public PipedFeatureIterator(FeatureIterator<SimpleFeature> iterator) {
    this.iterator = iterator;
  }
  
  /**
   * Checks whether a next element exists.
   */
  @Override
  public boolean hasNext() {
    return iterator.hasNext();
  }

  /**
   * Returns the next SimpleFeature;
   */
  @Override
  public SimpleFeature next() {
    return iterator.next();
  }

  /**
   * Not supported, because the {@link FeatureIterator} does not
   * support this functionality.
   * @throws UnsupportedOperationException always 
   */
  @Override
  public void remove() {
    throw new UnsupportedOperationException("PipedFeatureIterator.remove() not supported!");
  }
  

}
