/*******************************************************************************
 * Copyright (c) 2009 Martin O. J. Schmitz.
 * 
 * This file is part of the SCHMITZM library - a collection of utility 
 * classes based on Java 1.6, focusing (not only) on Java Swing 
 * and the Geotools library.
 * 
 * The SCHMITZM project is hosted at:
 * http://wald.intevation.org/projects/schmitzm/
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 3
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License (license.txt)
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 * or try this link: http://www.gnu.org/licenses/lgpl.html
 * 
 * Contributors:
 *     Martin O. J. Schmitz - initial API and implementation
 *     Stefan A. Krüger - additional utility classes
 ******************************************************************************/
package schmitzm.geotools.grid;

import java.util.SortedMap;
import java.util.TreeMap;

import org.geotools.coverage.grid.GridCoverage2D;

/**
 * Diese Klasse stellt Informationen ueber ein Raster dar, die mit
 * {@link GridUtil#determineStatistic(GridCoverage2D,int)} erstellt wurden.
 * @author <a href="mailto:martin.schmitz@koeln.de">Martin Schmitz</a> (University of Bonn/Germany)
 * @version 1.0
 */
public class GridStatistic {
  /** Breite des Rasters in Zellen.*/
  public int    widthC    = 0;
  /** Hoehe des Rasters in Zellen.*/
  public int    heightC   = 0;
  /** Kleinster horizontaler Zellen-Index des Rasters (inklusive).*/
  public int    minX     = 0;
  /** Kleinster vertikalter Zellen-Index des Rasters (inklusive).*/
  public int    minY     = 0;
  /** Groesster horizontaler Zellen-Index des Rasters (exklusive).*/
  public int    maxX     = 0;
  /** Groesster vertikaler Zellen-Index des Rasters (exklusive).*/
  public int    maxY     = 0;
  /** Reale Breite des Rasters.*/
  public double widthR    = 0;
  /** Reale Hoehe des Rasters.*/
  public double heightR   = 0;
  /** Latitude der suedwestlichen Ecke.*/
  public double latSW    = 0;
  /** Longitude der suedwestlichen Ecke.*/
  public double lonSW   = 0;
  /** Breite einer Raster-Zelle.*/
  public double cellWidth = 0;
  /** Hoehe des Rasters in Zellen.*/
  public double cellHeight   = 0;
  /** Werte, die NoData signalisieren. */
  public double[] noDataVal = new double[0];
  /** Kleinster Raster-Wert (ohne NoData-Zellen).*/
  public double minValue = 0;
  /** Groesster Raster-Wert (ohne NoData-Zellen).*/
  public double maxValue = 0;
  /** Summe aller Raster-Werte (ohne NoData-Zellen).*/
  public double sumValue = 0;
  /** Durchschnittlicher Raster-Wert (ohne NoData-Zellen).*/
  public double avgValue = 0;
  /** Anzahl an Wert-Zellen */
  public double cellCnt = 0;
  /** Anzahl an NoData-Zellen */
  public double nodataCnt = 0;
  /** Anzahl an Zellen unterschiedlicher Ausprägung - jede Wert erhält einen Key, Value ist die jeweilige Anzahl der Zellen ohne NaN */
  public SortedMap<String, Integer> histogramm = new TreeMap<String, Integer>();

}
