/*******************************************************************************
 * Copyright (c) 2009 Martin O. J. Schmitz.
 * 
 * This file is part of the SCHMITZM library - a collection of utility 
 * classes based on Java 1.6, focusing (not only) on Java Swing 
 * and the Geotools library.
 * 
 * The SCHMITZM project is hosted at:
 * http://wald.intevation.org/projects/schmitzm/
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 3
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License (license.txt)
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 * or try this link: http://www.gnu.org/licenses/lgpl.html
 * 
 * Contributors:
 *     Martin O. J. Schmitz - initial API and implementation
 *     Stefan A. Krüger - additional utility classes
 ******************************************************************************/
package schmitzm.geotools.gui;

import java.awt.BorderLayout;

import javax.swing.JFrame;

import org.geotools.feature.FeatureCollection;

import schmitzm.swing.table.SelectionTableModel;

/**
 * Dieses Fenster stellt eine {@link FeatureCollection} als Tabelle dar.
 * Optional wird links neben der Tabelle eine grafische Vorschau der in
 * der Tabelle selektierten Features angezeigt.
 * @see FeatureCollectionPane
 * @author <a href="mailto:martin.schmitz@koeln.de">Martin Schmitz</a> (University of Bonn/Germany)
 * @version 1.0
 */
public class FeatureCollectionFrame extends JFrame {
  /** Enthaelt die Tabelle (und den Preview-Bereich). */
  protected FeatureTablePane featuresPane = null;

  /**
   * Erzeugt ein neues Fenster inklusive Preview-Bereich fuer die in der
   * Tabelle selektieren Features.
   */
  public FeatureCollectionFrame() {
    this(null, true);
  }

  /**
   * Erzeugt ein neues Fenster.
   * @param geomPreview bestimmt, ob ein Preview-Bereich angezeigt wird ({@code true})
   *                    oder nicht ({@code false})
   */
  public FeatureCollectionFrame(boolean geomPreview) {
    this(null, geomPreview);
  }

  /**
   * Erzeugt ein neues Fenster inklusive Preview-Bereich fuer die in der
   * Tabelle selektieren Features.
   * @param fc angezeigte Features
   */
  public FeatureCollectionFrame(FeatureCollection fc) {
    this(fc, true);
  }

  /**
   * Erzeugt ein neues Fenster.
   * @param fc angezeigte Features
   * @param geomPreview bestimmt, ob ein Preview-Bereich angezeigt wird ({@code true})
   *                    oder nicht ({@code false})
   */
  public FeatureCollectionFrame(FeatureCollection fc, boolean geomPreview) {
    super();
    this.setLayout( new BorderLayout() );
    this.setDefaultCloseOperation( JFrame.HIDE_ON_CLOSE );
    this.featuresPane = new FeatureTablePane(fc,geomPreview) {
      protected void initGUI(boolean geomPreview) {
        super.initGUI(geomPreview);
        // Reset the table model to show a selection column
        featuresTable.setModel( new SelectionTableModel(featuresTableModel, featuresTable) );
        // Because SortableJTable is used, the first col is always a checkbox.
        // TODO: How wide is a CheckBox in differnet L'n'F s?
        int selCol = featuresTable.convertColumnIndexToModel(0);
        featuresTable.getColumnModel().getColumn(selCol).setMaxWidth(17);
        featuresTable.getColumnModel().getColumn(selCol).setMinWidth(17);
      }
    };
    this.getContentPane().add( featuresPane );
    this.pack();
  }

  /**
   * Setzt die anzuzeigende {@link FeatureCollection}.
   * @param fc Features
   */
  public void setFeatureCollection(FeatureCollection fc) {
    featuresPane.setFeatureCollection(fc);
  }

  /**
   * Liefert die angezeigte {@link FeatureCollection}.
   */
  public FeatureTablePane getFeatureCollectionPane() {
    return this.featuresPane;
  }
}
