package schmitzm.geotools.gui;

import java.awt.Font;
import java.text.DecimalFormat;
import java.text.DecimalFormatSymbols;
import java.util.Locale;

import org.geotools.referencing.CRS;
import org.geotools.referencing.crs.DefaultGeographicCRS;
import org.opengis.referencing.FactoryException;
import org.opengis.referencing.NoSuchAuthorityCodeException;

public class GridPanelFormatter_DHDN extends GridPanelFormatter {
	private static final Font font = new Font(Font.MONOSPACED, Font.BOLD, 11);
	final DecimalFormat numFormat = new DecimalFormat("###,###,###", new DecimalFormatSymbols(Locale.getDefault()));

	/**
	 * Creates a new formatter with DHDN / 3-degree Gauss zone 1 as CRS
	 *
	 * @param crs
	 *            the CRS the formatter can format
	 * @throws FactoryException
	 * @throws NoSuchAuthorityCodeException
	 */
	public GridPanelFormatter_DHDN()  {

		// # DHDN / 3-degree Gauss zone 1
		// <31461> +proj=tmerc +lat_0=0 +lon_0=3 +k=1.000000 +x_0=1500000 +y_0=0

		super(DefaultGeographicCRS.WGS84);

		try {
			setCRS(CRS.decode("EPSG:31461"));
		} catch (final Exception e) {
			throw new RuntimeException(e);
		}
	}
	@Override
	public double determineGridDistance(final GridPanel panel, final double mapMinCoord,
			final double mapMaxCoord, final int panelSize) {
		final double diff = Math.abs(mapMinCoord - mapMaxCoord);

		double dist;
		if (diff > 100000) {
			dist = Math.round(diff / 10000.) * 1000.;
		} else if (diff > 10000) {
			dist = Math.round(diff / 1000.) * 100.;
		}
		if (diff > 1000) {
			dist = Math.round(diff / 100.) * 10.;
		} else
			dist = 10;

		// Solange der Abstand zwischen 2 Unterteilungen weniger als 40/100
		// Pixel
		// betraegt --> Unterteilung verdoppeln
		while (diff != 0 && dist != 0
				&& panelSize / (diff / dist) < (panel.isVertical() ? 40 : 100))
			dist *= 2;

		// Solange der Abstand zwischen 2 Unterteilungen mehr als 120/300 Pixel
		// betraegt --> Unterteilung habieren
		while (diff != 0 && dist != 0
				&& panelSize / (diff / dist) > (panel.isVertical() ? 120 : 300))
			dist /= 2;

		return dist;
	}

	@Override
	public String formatCoordinate(final GridPanel panel, final double coord) {


		if (panel.isVertical()) {
			return numFormat.format(coord) + "H";
		} else {
			return numFormat.format(coord) + "R";
		}

	}

	@Override
	public Font getFont() {
		return font;
	}


	@Override
	public String getId() {
		return 	"10_DHDN";

	}

	@Override
	public String getTitle() {
		return RESOURCE.getString("schmitzm.geotools.gui.GridPanelFormatter_DHDN.title");
	}

	@Override
	public int getWidthForVertical(final GridPanel panel) {
		return 80;
	}


}
