/*******************************************************************************
 * Copyright (c) 2009 Martin O. J. Schmitz.
 * 
 * This file is part of the SCHMITZM library - a collection of utility 
 * classes based on Java 1.6, focusing (not only) on Java Swing 
 * and the Geotools library.
 * 
 * The SCHMITZM project is hosted at:
 * http://wald.intevation.org/projects/schmitzm/
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 3
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License (license.txt)
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 * or try this link: http://www.gnu.org/licenses/lgpl.html
 * 
 * Contributors:
 *     Martin O. J. Schmitz - initial API and implementation
 *     Stefan A. Krüger - additional utility classes
 ******************************************************************************/
package schmitzm.geotools.gui;

import java.awt.BorderLayout;
import java.beans.PropertyChangeEvent;
import java.beans.PropertyChangeListener;

import schmitzm.geotools.feature.FeatureUtil.GeometryForm;
import schmitzm.swing.JPanel;


/**
 * Diese Klasse stellt ein Fenster dar, in dem layer-basiert Geo-Objekte
 * grafisch dargestellt <b>und neue Vektor-Layer erstellt</b> werden koennen.
 * @author <a href="mailto:martin.schmitz@koeln.de">Martin Schmitz</a> (University of Bonn/Germany)
 * @version 1.0
 */
public class LayeredEditorFrame extends LayeredMapFrame {
  /** Toolbar, der die Editier-Funktionen steuert. */
  protected JMapEditorToolBar toolBar = null;
  /** Toolbar, der die Style-Funktionen steuert. */
  protected StyleToolBar styleBar = null;

  /**
   * Erzeugt ein neues (leeres) Editor-Fenster.
   */
  public LayeredEditorFrame() {
    this(null,"");
  }

  /**
   * Erzeugt ein neues (leeres) Editor-Fenster.
   * @param lmp {@link LayeredMapPane} welches zur Anzeige der Karten verwendet wird (wenn
   *            {@code null} wird eine neue {@link LayeredMapPane}-Instanz erzeugt)
   */
  public LayeredEditorFrame(LayeredMapPane lmp) {
    this(lmp,"");
  }

  /**
   * Erzeugt ein neues (leeres) Editor-Fenster.
   * @param title Titel des Fensters
   */
  public LayeredEditorFrame(String title) {
    this(null,title);
  }

  /**
   * Erzeugt ein neues (leeres) Editor-Fenster.
   * @param title Titel des Fensters
   * @param lmp {@link LayeredMapPane} welches zur Anzeige der Karten verwendet wird (wenn
   *            {@code null} wird eine neue {@link LayeredMapPane}-Instanz erzeugt)
   */
  public LayeredEditorFrame(LayeredMapPane lmp, String title) {
    super( lmp != null ? lmp : new LayeredMapPane(new GeoMapPane(new JMapEditorPane(),null,null, null)),title);
    if ( !(layeredMapPane.geoMapPane.mapPane instanceof JMapEditorPane) )
      throw new IllegalArgumentException("LayeredMapPane must contain a JEditorPane to use in LayeredEditorFrame.");
    this.toolBar  = new JMapEditorToolBar( (JMapEditorPane)layeredMapPane.geoMapPane.mapPane );
    this.styleBar = new StyleToolBar();
    // hide the tool bar for the map action, so only the
    // editing actions are available
    this.mapControl.setVisible(false);
    // Add a listener to the style bar, to apply every style
    // change to the map
    this.styleBar.addPropertyChangeListener( new PropertyChangeListener() {
      public void propertyChange(PropertyChangeEvent e) {
        JMapEditorPane editorPane = (JMapEditorPane)layeredMapPane.geoMapPane.mapPane;
        if ( e.getSource() == styleBar ) {
          editorPane.setEditorStyle( GeometryForm.POINT,   styleBar.createPointStyle() );
          editorPane.setEditorStyle( GeometryForm.LINE,    styleBar.createLineStyle() );
          editorPane.setEditorStyle( GeometryForm.POLYGON, styleBar.createPolygonStyle() );
          editorPane.refresh();
        }

      }
    });

    JPanel contentPane = new JPanel(new BorderLayout(0,5));
    JPanel toolPane    = new JPanel(new BorderLayout() );
    toolPane.add(toolBar, BorderLayout.NORTH);
    toolPane.add(styleBar, BorderLayout.SOUTH);
    contentPane.add( getContentPane(), BorderLayout.CENTER );
    contentPane.add( toolPane, BorderLayout.NORTH );
    setContentPane( contentPane );
  }
}
