/*******************************************************************************
 * Copyright (c) 2009 Martin O. J. Schmitz.
 * 
 * This file is part of the SCHMITZM library - a collection of utility 
 * classes based on Java 1.6, focusing (not only) on Java Swing 
 * and the Geotools library.
 * 
 * The SCHMITZM project is hosted at:
 * http://wald.intevation.org/projects/schmitzm/
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 3
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License (license.txt)
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 * or try this link: http://www.gnu.org/licenses/lgpl.html
 * 
 * Contributors:
 *     Martin O. J. Schmitz - initial API and implementation
 *     Stefan A. Krüger - additional utility classes
 ******************************************************************************/
package schmitzm.geotools.gui;

import java.awt.BorderLayout;
import java.awt.Color;
import java.awt.Graphics;

import javax.swing.SwingConstants;

import schmitzm.swing.JPanel;

/**
 * Stellt ein {@link BorderLayout}-Panel dar, in dem links ein
 * {@link RasterPositionLabel} und rechts ein {@link GeoPositionLabel}
 * dargestellt ist. Beide werden automatisch mit einem {@link SelectableXMapPane}
 * gekoppelt, so dass automatisch die Anzeige der Labels aktualisiert wird,
 * sobald sich der Cursor ueber die Karte bewegt.
 * @author <a href="mailto:martin.schmitz@koeln.de">Martin Schmitz</a> (University of Bonn/Germany)
 * @version 1.0
 */
public class MapPaneStatusBar extends JPanel {
  /** Zeigt die Raster-Koordinaten und den Rasterwert des obersten sichtbaren
   *  Rasters an */
  protected RasterPositionLabel rasterPositionLabel = null;
  /** Zeigt die Welt-Koordinaten an */
  protected GeoPositionLabel geoPositionLabel = null;

  /**
   * Erzeugt einen neuen Status-Balken.
   * @param mapPane Karte mit der die Labels gekoppelt werden
   */
  public MapPaneStatusBar(SelectableXMapPane mapPane) {
    this(mapPane,null,null);
  }

  /**
   * Erzeugt einen neuen Status-Balken.
   * @param mapPane Karte mit der die Labels gekoppelt werden
   * @param rasterPosLabel Label, in dem die Raster-Koordinaten angezeigt
   *        werden (wenn {@code null}, wird ein neues {@link RasterPositionLabel} erzeugt).
   * @param geoPosLabel Label, in dem die Geo-Koordinaten angezeigt
   *        werden (wenn {@code null}, wird ein neues {@link GeoPositionLabel} erzeugt).
   */
  public MapPaneStatusBar(SelectableXMapPane mapPane, RasterPositionLabel rasterPosLabel, GeoPositionLabel geoPosLabel) {
    super();
    setLayout( new BorderLayout() );
    // rechts: Anzeige der aktuellen Welt-Koordinaten
    this.geoPositionLabel = (geoPosLabel != null) ? geoPosLabel : new GeoPositionLabel(2);
    geoPositionLabel.setHorizontalAlignment(SwingConstants.RIGHT);
    geoPositionLabel.setFractionDigits(1);
    this.add(geoPositionLabel,BorderLayout.EAST);
    // links: Anzeige
    rasterPositionLabel = (rasterPosLabel != null) ? rasterPosLabel : new RasterPositionLabel(2);
    this.add(rasterPositionLabel,BorderLayout.WEST);

    // Labels mit dem MapPane koppeln
    mapPane.addMouseMotionListener(rasterPositionLabel);
    mapPane.addMouseListener(geoPositionLabel);
    mapPane.addMouseMotionListener(geoPositionLabel);
  }
  
  /**
   * Nuetzlich wenn die Componente gedruckt (z.B. wenn ein Screenshot gemacht wird) wird. Dann werden wird der
   * Hintergrund auf WEISS gesetzt.
   *
   * @author <a href="mailto:skpublic@wikisquare.de">Stefan Alfons
   *         Kr&uuml;ger</a>
   */
  @Override
  public void print(Graphics g) {
      Color orig = getBackground();
      setBackground(Color.WHITE);
      // wrap in try/finally so that we always restore the state
      try {
          super.print(g);
      } finally {
          setBackground(orig);
      }
  }
}
