/*******************************************************************************
 * Copyright (c) 2009 Martin O. J. Schmitz.
 * 
 * This file is part of the SCHMITZM library - a collection of utility 
 * classes based on Java 1.6, focusing (not only) on Java Swing 
 * and the Geotools library.
 * 
 * The SCHMITZM project is hosted at:
 * http://wald.intevation.org/projects/schmitzm/
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 3
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License (license.txt)
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 * or try this link: http://www.gnu.org/licenses/lgpl.html
 * 
 * Contributors:
 *     Martin O. J. Schmitz - initial API and implementation
 *     Stefan A. Krüger - additional utility classes
 ******************************************************************************/
package schmitzm.geotools.gui;

import java.awt.Graphics;
import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.awt.Insets;
import java.text.DecimalFormat;

import javax.swing.BorderFactory;
import javax.swing.JLabel;

import schmitzm.swing.JPanel;

/**
 * Diese Klasse stellt einen Massstab-Balken ({@link ScalePanel}) und die
 * dazugehoerende Aufloesung in Metern pro Bildschirm-Pixel dar.
 * @author <a href="mailto:martin.schmitz@koeln.de">Martin Schmitz</a> (University of Bonn/Germany)
 * @version 1.0
 */
public class ScalePane extends JPanel{
  private static final DecimalFormat numFormat = new DecimalFormat("###,###,##0.00");

  /** Massstab-Balken */
  private ScalePanel scalePanel  =  new ScalePanel();
  /** Label in dem die Aufloesung in Meter pro Pixel angezeigt wird. */
  private JLabel     scaleLabel  = new JLabel("");

  /**
   * Erzeugt eine Mass-Stab.
   */
  public ScalePane() {
	  setBorder(BorderFactory.createEmptyBorder(5, 0, 0, 0));
    setScale(1.0);
    this.setLayout( new GridBagLayout() );
    this.add( getScalePanel(), new GridBagConstraints(0,0,2,1,1.0,1.0,GridBagConstraints.CENTER,GridBagConstraints.BOTH,new Insets(0,0,0,0),0,0) );
   	this.getScaleLabel().setHorizontalAlignment(JLabel.LEFT);
   	this.add( getScaleLabel(), new GridBagConstraints(0,1,1,1,0.5,0.0,GridBagConstraints.NORTHWEST,GridBagConstraints.NONE,new Insets(0,0,0,0),0,0) );
  }

  /**
   * Liefert die dargestellte Aufloesung in Pixel pro Meter.
   */
  public double getScaleInPixels() {
    return getScalePanel().getScaleInPixels();
  }

  /**
   * Liefert die dargestellte Aufloesung in Metern pro Pixel.
   */
  public double getScaleInMeters() {
    return getScalePanel().getScaleInMeters();
  }

  /**
   * Setzt die Aufloesung des Mass-Stabs und aktualisiert die Anzeige der
   * Komponente.
   * @param meters Meter, die durch einen Bildschirm-Pixel repraesentiert werden
   */
  public void setScale(double meters) {
    getScalePanel().setScale(meters);
    
    // TODO i8n
    getScaleLabel().setText("1 pixel = "+numFormat.format(meters)+"m");
    repaint();
  }

  /**
   * Setzt die Aufloesung des Mass-Stabs und aktualisiert die Anzeige der
   * Komponente.
   * @param pixels Anzahl an Pixeln, die einen Meter repraesentieren werden
   * @exception Ill
   */
  public void setScale(long pixels) {
    getScalePanel().setScale(pixels);
    
    // TODO i8n
    getScaleLabel().setText(pixels+" pixel = 1m");
    repaint();
  }
  
  /**
   * Nuetzlich wenn die Componente gedruckt (z.B. wenn ein Screenshot gemacht wird) wird. Diese Angabe macht kaum sinn wenn gedruckt wird, oder?! 
   *
   * @author <a href="mailto:skpublic@wikisquare.de">Stefan Alfons
   *         Kr&uuml;ger</a>
   */
  @Override
  public void print(Graphics g) {
	  return;
//      final Color orig = getBackground();
//      setBackground(Color.WHITE);
//      // remove the informatil   xxx pixel = 1m
//      final String backupPixelText = scaleLabel.getText();
//      scaleLabel.setText("");
//      // wrap in try/finally so that we always restore the state
//      try {
//          super.print(g);
//      } finally {
//          setBackground(orig);
//          scaleLabel.setText(backupPixelText);
//      }
  }

public void setScaleLabel(JLabel scaleLabel) {
	this.scaleLabel = scaleLabel;
}

public JLabel getScaleLabel() {
	return scaleLabel;
}

public void setScalePanel(ScalePanel scalePanel) {
	this.scalePanel = scalePanel;
}

public ScalePanel getScalePanel() {
	return scalePanel;
}

}
