/*******************************************************************************
 * Copyright (c) 2009 Martin O. J. Schmitz.
 * 
 * This file is part of the SCHMITZM library - a collection of utility 
 * classes based on Java 1.6, focusing (not only) on Java Swing 
 * and the Geotools library.
 * 
 * The SCHMITZM project is hosted at:
 * http://wald.intevation.org/projects/schmitzm/
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 3
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License (license.txt)
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 * or try this link: http://www.gnu.org/licenses/lgpl.html
 * 
 * Contributors:
 *     Martin O. J. Schmitz - initial API and implementation
 *     Stefan A. Krüger - additional utility classes
 ******************************************************************************/
package schmitzm.geotools.map.event;

import schmitzm.geotools.gui.SelectableXMapPane;

import com.vividsolutions.jts.geom.Envelope;

/**
 * Diese Klasse stellt ein Ereignis dar, das ein {@link SelectableXMapPane} ausloest,
 * wenn der Anwender (irgendeinen) einen Bereich in der Karte ausgewaehlt hat,
 * auch wenn dort keine Objekte selektiert wurden.
 * @author <a href="mailto:martin.schmitz@koeln.de">Martin Schmitz</a> (University of Bonn/Germany)
 * @version 1.0
 */
public class GeneralSelectionEvent extends MapPaneEvent {
  /** Bereich der selektiert wurde. */
  protected Envelope envelope    = null;

  /**
   * Erzeugt ein neues Ereignis.
   * @param source Karte in der die Selektion vorgenommen wurde
   * @param envelope  Bereich der selektiert wurde
   * @param sourceObject Objekt, das die Selektion initiiert hat (wenn {@code null},
   *                     wird das MapPane als Ausloeser gesetzt)
   */
  public GeneralSelectionEvent(SelectableXMapPane source, Envelope envelope, Object sourceObject) {
    super(source, sourceObject);
    this.envelope = envelope;
  }

  /**
   * Erzeugt ein neues Ereignis.
   * @param sourceMap Karte in der die Selektion vorgenommen wurde
   * @param envelope  Bereich der selektiert wurde
   */
  public GeneralSelectionEvent(SelectableXMapPane sourceMap, Envelope envelope) {
    this(sourceMap,envelope,null);
  }


  /**
   * Liefert den Bereich ueber den selektiert wurde.
   */
  public Envelope getSelectionRange() {
    return envelope;
  }
}
