/*******************************************************************************
 * Copyright (c) 2009 Martin O. J. Schmitz.
 * 
 * This file is part of the SCHMITZM library - a collection of utility 
 * classes based on Java 1.6, focusing (not only) on Java Swing 
 * and the Geotools library.
 * 
 * The SCHMITZM project is hosted at:
 * http://wald.intevation.org/projects/schmitzm/
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 3
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License (license.txt)
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 * or try this link: http://www.gnu.org/licenses/lgpl.html
 * 
 * Contributors:
 *     Martin O. J. Schmitz - initial API and implementation
 *     Stefan A. Krüger - additional utility classes
 ******************************************************************************/
package schmitzm.geotools.map.event;

import java.awt.geom.Point2D;

import org.geotools.map.MapLayer;

import schmitzm.geotools.gui.SelectableXMapPane;

import com.vividsolutions.jts.geom.Envelope;

/**
 * Diese Klasse stellt ein Ereignis dar, das ein {@link SelectableXMapPane} ausloest,
 * wenn der Anwender den Wert eines Rasters in der Karte ausgewaehlt hat.
 *
 * @author <a href="mailto:martin.schmitz@koeln.de">Martin Schmitz</a> (University of Bonn/Germany)
 *
 * @version 1.0
 *
 *
 * Da Raster auch mehrere Baender haben kann, habe ich von ObjectSelectionEvent
 * Double auf ObjectSelectionEvent double[] geaendert. Die laenge des double array
 * entspricht der Anzahl der Baender.
 *
 * @author <a href="mailto:skpublic@wikisquare.de">Stefan Alfons Kr&uuml;ger</a>
 *
 * @version 1.1
 *
 */
public class GridCoverageValueSelectedEvent extends ObjectSelectionEvent<double[]> {
  /** Punkt auf den geklickt wurde */
  private Point2D point = null;

  /**
   * Erzeugt ein neues Ereignis.
   * @param sourceMap      Karte in der die Selektion vorgenommen wurde
   * @param sourceLayer    Layer aus dem die Features stammen
   * @param point          Punkt der selektiert wurde
   * @param result         selektierters Teil-Raster
   * @param sourceObject   Objekt, das die Selektion initiiert hat (wenn {@code null},
   *                       wird das MapPane als Ausloeser gesetzt)
   */
  public GridCoverageValueSelectedEvent(SelectableXMapPane sourceMap, MapLayer sourceLayer, Point2D point, double[] result, Object sourceObject) {
    super(sourceMap,sourceLayer,new Envelope(point.getX(),point.getX(),point.getY(),point.getY()),result, sourceObject);
    this.point = point;
  }

  /**
   * Erzeugt ein neues Ereignis.
   * @param sourceMap      Karte in der die Selektion vorgenommen wurde
   * @param sourceLayer    Layer aus dem die Features stammen
   * @param point          Punkt der selektiert wurde
   * @param result         selektierters Teil-Raster
   */
  public GridCoverageValueSelectedEvent(SelectableXMapPane sourceMap, MapLayer sourceLayer, Point2D point, double[] result) {
    this(sourceMap,sourceLayer,point,result,null);
  }

  /**
   * Liefert den selektierten Punkt.
   */
  public Point2D getSelectionPoint() {
    return point;
  }

}
