/*******************************************************************************
 * Copyright (c) 2009 Martin O. J. Schmitz.
 * 
 * This file is part of the SCHMITZM library - a collection of utility 
 * classes based on Java 1.6, focusing (not only) on Java Swing 
 * and the Geotools library.
 * 
 * The SCHMITZM project is hosted at:
 * http://wald.intevation.org/projects/schmitzm/
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 3
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License (license.txt)
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 * or try this link: http://www.gnu.org/licenses/lgpl.html
 * 
 * Contributors:
 *     Martin O. J. Schmitz - initial API and implementation
 *     Stefan A. Krüger - additional utility classes
 ******************************************************************************/
package schmitzm.geotools.map.event;

import schmitzm.geotools.gui.SelectableXMapPane;
import skrueger.geotools.XMapPane;

/**
 * Diese Klasse stellt ein Ereignis dar, das von einem {@link SelectableXMapPane}
 * ausgeloest wurde (z.B. Aenderung der Aufloesung).
 * @author <a href="mailto:martin.schmitz@koeln.de">Martin Schmitz</a> (University of Bonn/Germany)
 * @version 1.0
 */
public abstract class MapPaneEvent {
  /** Beinhaltet das {@link XMapPane}, das das Ereignis ausgeloest hat */
  protected SelectableXMapPane source = null;
  /** Beinhaltet ein Objekt, das das Ereignis initiiert hat */
  protected Object sourceObject = null;

  /**
   * Erzeugt ein neues Ereignis.
   * @param source {@link XMapPane}, das das Ereignis ausgeloest hat
   * @param sourceObject Objeckt, das das Ereignis initiiert hat (wenn {@code null},
   *        wird das MapPane als Ausloeser gesetzt)
   */
  public MapPaneEvent(SelectableXMapPane source, Object sourceObject) {
    this.source       = source;
    this.sourceObject = (sourceObject != null) ? sourceObject : source;
  }

  /**
   * Erzeugt ein neues Ereignis.
   * @param source {@link XMapPane}, das das Ereignis ausgeloest hat
   */
  public MapPaneEvent(SelectableXMapPane source) {
    this(source,null);
  }

  /**
   * Liefert das {@link SelectableXMapPane}, das das Ereignis ausgeloest hat.
   */
  public SelectableXMapPane getSource() {
    return source;
  }

  /**
   * Liefert das Object, das das Ereignis initiiert hat.
   */
  public Object getSourceObject() {
    return sourceObject;
  }
}
