/*******************************************************************************
 * Copyright (c) 2009 Martin O. J. Schmitz.
 * 
 * This file is part of the SCHMITZM library - a collection of utility 
 * classes based on Java 1.6, focusing (not only) on Java Swing 
 * and the Geotools library.
 * 
 * The SCHMITZM project is hosted at:
 * http://wald.intevation.org/projects/schmitzm/
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 3
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License (license.txt)
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 * or try this link: http://www.gnu.org/licenses/lgpl.html
 * 
 * Contributors:
 *     Martin O. J. Schmitz - initial API and implementation
 *     Stefan A. Krüger - additional utility classes
 ******************************************************************************/
package schmitzm.geotools.map.event;

import org.geotools.map.MapLayer;

import schmitzm.geotools.gui.SelectableXMapPane;
import skrueger.geotools.XMapPane;

import com.vividsolutions.jts.geom.Envelope;

/**
 * Diese Klasse stellt eine Oberklasse fuer die Ereignisse dar, die ein
 * {@link XMapPane} ausloest, wenn der Anwender einen Bereich in der Karte ausgewaehlt hat
 * und dabei Objekte selektiert wurde.
 * @author <a href="mailto:martin.schmitz@koeln.de">Martin Schmitz</a> (University of Bonn/Germany)
 * @version 1.0
 */
public class ObjectSelectionEvent<E> extends GeneralSelectionEvent {
  private MapLayer          sourceLayer = null;
  private E                 result      = null;

  /**
   * Erzeugt ein neues Ereignis.
   * @param sourceMap      Karte in der die Selektion vorgenommen wurde
   * @param sourceLayer    Layer aus dem die Features stammen
   * @param envelope       Bereich der selektiert wurde
   * @param result         selektierte Objekte
   * @param sourceObject   Objekt, das die Selektion initiiert hat (wenn {@code null},
   *                       wird das MapPane als Ausloeser gesetzt)
   */
  public ObjectSelectionEvent(SelectableXMapPane sourceMap, MapLayer sourceLayer, Envelope envelope, E result, Object sourceObject) {
    super(sourceMap,envelope,sourceObject);
    this.sourceLayer = sourceLayer;
    this.result      = result;
  }

  /**
   * Erzeugt ein neues Ereignis.
   * @param sourceMap      Karte in der die Selektion vorgenommen wurde
   * @param sourceLayer    Layer aus dem die Features stammen
   * @param envelope       Bereich der selektiert wurde
   * @param result         selektierte Objekte
   */
  public ObjectSelectionEvent(SelectableXMapPane sourceMap, MapLayer sourceLayer, Envelope envelope, E result) {
    this(sourceMap,sourceLayer,envelope, result, null);
  }
  /**
   * Liefert das Layer aus dem die Features stammen.
   */
  public MapLayer getSourceLayer() {
    return sourceLayer;
  }

  /**
   * Liefert die selektierten Objekte.
   */
  public E getSelectionResult() {
    return result;
  }

}
