/*******************************************************************************
 * Copyright (c) 2009 Martin O. J. Schmitz.
 * 
 * This file is part of the SCHMITZM library - a collection of utility 
 * classes based on Java 1.6, focusing (not only) on Java Swing 
 * and the Geotools library.
 * 
 * The SCHMITZM project is hosted at:
 * http://wald.intevation.org/projects/schmitzm/
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 3
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License (license.txt)
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 * or try this link: http://www.gnu.org/licenses/lgpl.html
 * 
 * Contributors:
 *     Martin O. J. Schmitz - initial API and implementation
 *     Stefan A. Krüger - additional utility classes
 ******************************************************************************/
package schmitzm.geotools.styling;

import java.util.HashMap;

import org.geotools.styling.ColorMap;

/**
 * Diese Klasse verwaltet eine Liste von {@linkplain ColorMap Farbpaletten}
 * fuer Rasterdaten als Tupel ({@code Name}, {@link ColorMap}).
 * Zudem kann eine Farbpalette als Standard deklariert werden.
 * @author Martin Schmitz
 * @version 1.0
 */
public class ColorMapManager extends HashMap<String,ColorMap> {
  /** Name der Standard-Farbtabelle. */
  protected String defaultColorMap = null;

  /**
   * Erzeugt einen neuen {@code ColorMapManager}.
   */
  public ColorMapManager() {
    super();
  }

  /**
   * Fuegt dem Manager eine Farbpalette hinzu.
   * @param name Bezeichnung der Farbpalette
   * @param map  Farbpalette
   * @param setDefault  ist dieses Flag gesetzt, wird diese Farbpalette als
   *                    Standard festgelegt
   */
  public void put(String name, ColorMap map, boolean setDefault) {
    put(name,map);
    if ( setDefault )
      setDefaultColorMap( name );
  }

  /**
   * Setzt die Standard-Farbpalette.
   * @param name Bezeichnung der Farbpalette
   */
  public void setDefaultColorMap(String name) {
    defaultColorMap = name;
  }

  /**
   * Liefert die Bezeichnung der Standard-Farbpalette.
   */
  public String getDefaultColorMapName() {
    return defaultColorMap;
  }

  /**
   * Liefert die Standard-Farbpalette.
   */
  public ColorMap getDefaultColorMap() {
    return get(defaultColorMap);
  }

}
