/*******************************************************************************
 * Copyright (c) 2009 Martin O. J. Schmitz.
 * 
 * This file is part of the SCHMITZM library - a collection of utility 
 * classes based on Java 1.6, focusing (not only) on Java Swing 
 * and the Geotools library.
 * 
 * The SCHMITZM project is hosted at:
 * http://wald.intevation.org/projects/schmitzm/
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 3
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License (license.txt)
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 * or try this link: http://www.gnu.org/licenses/lgpl.html
 * 
 * Contributors:
 *     Martin O. J. Schmitz - initial API and implementation
 *     Stefan A. Krüger - additional utility classes
 ******************************************************************************/
package schmitzm.io;

import java.io.File;
import java.io.FileDescriptor;
import java.io.FileNotFoundException;

/**
 * Diese Klasse erweitert den {@link java.io.FileOutputStream} in der Art, dass
 * eine Referenz auf die zugrunde liegende Datei gespeichert wird. Diese kann
 * ueber {@link #getFile()} abgerufen werden.
 * @author <a href="mailto:martin.schmitz@koeln.de">Martin Schmitz</a> (University of Bonn/Germany)
 * @version 1.0
 */
public class FileOutputStream extends java.io.FileOutputStream {
  private File file = null;

  /**
   * Erzeugt einen neuen <code>FileOutputStream</code>.<br>
   * Siehe {@link java.io.FileOutputStream#FileOutputStream(File)}.
   */
  public FileOutputStream(File file) throws FileNotFoundException {
    super(file);
    this.file = file;
  }

  /**
   * Erzeugt einen neuen <code>FileOutputStream</code>.<br>
   * Siehe {@link java.io.FileOutputStream#FileOutputStream(File,boolean)}.
   */
  public FileOutputStream(File file, boolean append) throws FileNotFoundException {
    super(file,append);
    this.file = file;
  }

  /**
   * Erzeugt einen neuen <code>FileOutputStream</code>.<br>
   * Siehe {@link java.io.FileOutputStream#FileOutputStream(FileDescriptor)}.
   */
  public FileOutputStream(FileDescriptor fdObj) throws FileNotFoundException {
    super(fdObj);
  }

  /**
   * Erzeugt einen neuen <code>FileOutputStream</code>.<br>
   * Siehe {@link java.io.FileOutputStream#FileOutputStream(String)}.
   */
  public FileOutputStream(String name) throws FileNotFoundException {
    super(name);
    this.file = new File(name);
  }

  /**
   * Erzeugt einen neuen <code>FileOutputStream</code>.<br>
   * Siehe {@link java.io.FileOutputStream#FileOutputStream(String,boolean)}.
   */
  public FileOutputStream(String name, boolean append) throws FileNotFoundException {
    super(name,append);
    this.file = new File(name);
  }


  /**
   * Liefert die Datei, auf der der OutputStream basiert.
   * @return <code>null</code> falls der Stream auf einem <code>FileDescriptor</code>
   *         basiert
   * @return File
   */
  public File getFile() {
    return file;
  }
}
