/*******************************************************************************
 * Copyright (c) 2009 Martin O. J. Schmitz.
 * 
 * This file is part of the SCHMITZM library - a collection of utility 
 * classes based on Java 1.6, focusing (not only) on Java Swing 
 * and the Geotools library.
 * 
 * The SCHMITZM project is hosted at:
 * http://wald.intevation.org/projects/schmitzm/
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 3
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License (license.txt)
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 * or try this link: http://www.gnu.org/licenses/lgpl.html
 * 
 * Contributors:
 *     Martin O. J. Schmitz - initial API and implementation
 *     Stefan A. Krüger - additional utility classes
 ******************************************************************************/
package schmitzm.io.dyntxt;

import java.io.IOException;
import java.io.OutputStream;
import java.util.Vector;

/**
 * Diese Klasse stellt einen allgemeinen Block von dynamischen Elementen dar.
 * @author Martin Schmitz
 * @version 1.0
 */
public class DynamicBlock extends DynamicElement {
  public Vector elements = new Vector();

  /**
   * Erzeugt einen neuen Block.
   * @param id identifieziert den Block gegenueber dem <code>DynamicInputProvider</code>
   */
  public DynamicBlock(String id) {
    super(id);
  }

  /**
   * Erzeugt einen neuen Block.
   * @param id identifieziert den Block gegenueber dem <code>DynamicInputProvider</code>
   * @param father anderes dynamisches Element, welches den Block beinhaltet
   */
  public DynamicBlock(String id, DynamicElement father) {
    super(id, father);
  }

  /**
   * Fuegt dem Block ein dynamisches Element hinzu.
   * @param idx     Position, an der das Element eingefuegt wird.
   * @param element einzufuegendes dynamisches Element
   * @exception java.lang.ArrayIndexOutOfBoundsException falls
   *            <code>idx < 0 || idx > size()</code>
   */
  public void add(int idx, DynamicElement element) {
    elements.add(idx,element);
  }

  /**
   * Fuegt ein dynamisches Element am Ende des Blocks an.
   * @param element einzufuegendes dynamisches Element
   */
  public void add(DynamicElement element) {
    elements.add(element);
  }

  /**
   * Liefert die aktuelle Anzahl an Elementen im Block.
   */
  public int size() {
    return elements.size();
  }

  /**
   * Liefert die aktuelle Anzahl an Elementen im Block.
   */
  public boolean isEmpty() {
    return size()==0;
  }

  /**
   * Loescht alle Elemente des Blocks.
   */
  public void clear() {
    elements.clear();
  }

  /**
   * Fuehrt nacheinander alle dynamischen Elemente des Blocks der Reihe nach aus.
   * @param inputProvider verarbeitet die Loops und Fields im Block
   * @param output        hier wird die Ausgabe reingeschrieben
   * @exception java.io.IOException falls das Schreiben in den Stream fehlschlaegt
   */
  public void performElement(DynamicInputProvider inputProvider, OutputStream output) throws IOException {
    for (int i=0; i<elements.size(); i++)
      ((DynamicElement)elements.elementAt(i)).performElement(inputProvider, output);
  }
}
