/*******************************************************************************
 * Copyright (c) 2009 Martin O. J. Schmitz.
 * 
 * This file is part of the SCHMITZM library - a collection of utility 
 * classes based on Java 1.6, focusing (not only) on Java Swing 
 * and the Geotools library.
 * 
 * The SCHMITZM project is hosted at:
 * http://wald.intevation.org/projects/schmitzm/
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 3
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License (license.txt)
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 * or try this link: http://www.gnu.org/licenses/lgpl.html
 * 
 * Contributors:
 *     Martin O. J. Schmitz - initial API and implementation
 *     Stefan A. Krüger - additional utility classes
 ******************************************************************************/
package schmitzm.io.dyntxt;

/**
 * Dieses Interface definiert eine Klasse, welche die dynamischen
 * Eingaben fuer einen dynamischen Text bereitstellt.<br>
 * Hierzu zaehlen:
 * <ol>
 * <li>Das Beenden von Schleifen</li>
 * <li>Das Fuellen von dynmischen Eingabe-Feldern</li>
 * </ol>
 * @see schmitzm.io.dyntxt.DynamicTextGenerator
 * @author Martin Schmitz
 * @version 1.0
 */
public interface DynamicInputProvider {
  /**
   * Wird <b>vor</b> jedem Schleifen-Durchlaufs aufgerufen. In dieser Methode
   * kann der InputProvider die Daten fuer die in der Schleife referenzierten
   * Felder ermitteln.<br>
   * Ueber <code>DynamicLoop.getActualLoop()</code> kann der aktuelle
   * Schleifenzaehler ermittelt werden (0 vor dem ersten Durchlauf).
   * Soll ein weiterer Schleifendurchlauf ausgefuert werden, muss die Methode
   * <code>true</code> liefern, andernfalls <code>false</code>.
   * @param loop die auszufuehrende Schleife (kann ueber <code>getID()</code>
   *        identifiziert werden

   */
  public boolean performLoop(DynamicLoop loop);

  /**
   * Wird fuer jedes Eingabefeld aufgerufen und liefert den Wert, der im dynamischen
   * Text fuer das Feld eingesetzt werden soll.<br>
   * Die aktuelle Schleife, in der sich das Feld befindet (und somit deren
   * Durchlauf), kann ueber <code>field.getFather( DynamicLoop.class )</code>
   * ermittelt werden.
   * @param field das zu fuellende Feld (kann ueber <code>getID()</code>
   *        identifiziert werden
   */
  public String performField(DynamicField field);
}
