/*******************************************************************************
 * Copyright (c) 2009 Martin O. J. Schmitz.
 * 
 * This file is part of the SCHMITZM library - a collection of utility 
 * classes based on Java 1.6, focusing (not only) on Java Swing 
 * and the Geotools library.
 * 
 * The SCHMITZM project is hosted at:
 * http://wald.intevation.org/projects/schmitzm/
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 3
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License (license.txt)
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 * or try this link: http://www.gnu.org/licenses/lgpl.html
 * 
 * Contributors:
 *     Martin O. J. Schmitz - initial API and implementation
 *     Stefan A. Krüger - additional utility classes
 ******************************************************************************/
package schmitzm.io.dyntxt;

import java.io.IOException;
import java.io.OutputStream;

/**
 * Diese Klasse stellt eine Schleife dar, welche eine Reihe von Elementen
 * beihaltet. Wie lange die Schleife ausgefuehrt wird, wird durch
 * <code>DynamicInputProvider.performLoop(..)</code> bestimmt.
 * @see schmitzm.io.dyntxt.DynamicInputProvider
 * @author Martin Schmitz
 * @version 1.0
 */
public class DynamicLoop extends DynamicBlock {
  private int loopNo = 0;

  /**
   * Erzeugt ein neues Schleifen-Element.
   * @param id identifieziert die Schleife gegenueber dem <code>DynamicInputProvider</code>
   */
  public DynamicLoop(String id) {
    super(id);
  }

  /**
   * Erzeugt ein neues Schleifen-Element.
   * @param id identifieziert die Schleife gegenueber dem <code>DynamicInputProvider</code>
   * @param father anderes dynamisches Element, welches die Schleife beinhaltet
   */
  public DynamicLoop(String id, DynamicElement father) {
    super(id,father);
  }

  /**
   * Liefert den aktuellen Schleifen-Zaehler (beginnend bei 0).
   * Dieser wird zu Beginn der Ausfuehrung (<code>performElement(..)</code>)
   * auf 0 zurueckgesetzt.
   * @see #performElement(DynamicInputProvider,OutputStream)
   */
  public int getActualLoop() {
    return this.loopNo;
  }

  /**
   * Fuehrt solange alle dynamischen Elemente des Blocks aus, bis der
   * <code>DynamicInputProvider</code> die Schleife beendet.
   * @param inputProvider verarbeitet die Loops und Fields im Loop-Block
   * @param output        hier wird die Ausgabe reingeschrieben
   * @exception java.io.IOException falls das Schreiben in den Stream fehlschlaegt
   * @see schmitzm.io.dyntxt.DynamicInputProvider#performLoop(DynamicLoop)
   */
  public void performElement(DynamicInputProvider inputProvider, OutputStream output) throws IOException {
    for (this.loopNo=0; inputProvider.performLoop(this); loopNo++)
      super.performElement(inputProvider,output);
  }
}
