/*******************************************************************************
 * Copyright (c) 2009 Martin O. J. Schmitz.
 * 
 * This file is part of the SCHMITZM library - a collection of utility 
 * classes based on Java 1.6, focusing (not only) on Java Swing 
 * and the Geotools library.
 * 
 * The SCHMITZM project is hosted at:
 * http://wald.intevation.org/projects/schmitzm/
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 3
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License (license.txt)
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 * or try this link: http://www.gnu.org/licenses/lgpl.html
 * 
 * Contributors:
 *     Martin O. J. Schmitz - initial API and implementation
 *     Stefan A. Krüger - additional utility classes
 ******************************************************************************/
package schmitzm.io.dyntxt;

import java.io.IOException;
import java.io.OutputStream;

/**
 * Diese Klasse stellt einen dynamisches Element dar, welches einen
 * statischen Text speichert.
 * @author Martin Schmitz
 * @version 1.0
 */
public class StaticText extends DynamicElement {
  private String text = "";

  /**
   * Erzeugt ein neues Text-Element. Als ID wird diesem ein Leerstring
   * zugeordnet. Dies ist unproblematisch, da das statische Text-Feld
   * nicht durch einem <code>DynamicInputProvider</code> identifiziert
   * werden muss.
   * @param text statischer Text
   */
  public StaticText(String text) {
    this(null,text);
  }

  /**
   * Erzeugt ein neues Text-Element.
   * @param father anderes dynamisches Element, welches die Schleife beinhaltet
   * @param text statischer Text
   */
  public StaticText(DynamicElement father, String text) {
    this("",father,text);
  }

  /**
   * Erzeugt ein neues Feld-Element.
   * @param id identifieziert das Feld gegenueber dem <code>DynamicInputProvider</code>
   * @param father anderes dynamisches Element, welches die Schleife beinhaltet
   * @param text statischer Text
   */
  public StaticText(String id, DynamicElement father, String text) {
    super(id,father);
    this.text = text;
  }

  /**
   * Liefert den statischen Text.
   */
  public String getText() {
    return text;
  }

  /**
   * Schreibt den statischen Text einen Ausgabe-Stream.
   * @param inputProvider verarbeitet die Fields (hat keine Bedeutung fuer diese Funktion)
   * @param output        hier wird die Ausgabe reingeschrieben
   * @exception java.io.IOException falls das Schreiben in den Stream fehlschlaegt
   */
  public void performElement(DynamicInputProvider inputProvider, OutputStream output) throws IOException {
    output.write( getText().getBytes() );
  }
}
