/*******************************************************************************
 * Copyright (c) 2009 Martin O. J. Schmitz.
 * 
 * This file is part of the SCHMITZM library - a collection of utility 
 * classes based on Java 1.6, focusing (not only) on Java Swing 
 * and the Geotools library.
 * 
 * The SCHMITZM project is hosted at:
 * http://wald.intevation.org/projects/schmitzm/
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 3
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License (license.txt)
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 * or try this link: http://www.gnu.org/licenses/lgpl.html
 * 
 * Contributors:
 *     Martin O. J. Schmitz - initial API and implementation
 *     Stefan A. Krüger - additional utility classes
 ******************************************************************************/
package schmitzm.jfree;

import java.util.HashMap;
import java.util.Map;

import org.jfree.data.general.Dataset;
import org.jfree.data.general.DatasetGroup;

/**
 * This {@link DatasetGroup} is raped! It provides the possibility to add
 * individual meta to a {@link Dataset}.
 * Because a {@link DatasetGroup} can be set to <b>every</b> {@link Dataset}, the
 * mata data can be accessed everywhere the {@link Dataset} can be accessed,
 * independently of the concrete {@link Dataset}.<br>
 * <b>Note:</b><br>
 * If a "real" {@link DatasetGroup} is set for a {@link Dataset}, the meta data
 * is lost!!
 * @author <a href="mailto:martin.schmitz@koeln.de">Martin Schmitz</a>
 */
public class DatasetMetaDataGroup extends DatasetGroup {
  /** Holds meta data objects. */
  protected Map<String,Object> metadata = new HashMap<String, Object>();

  /**
   * Creates a new meta data object.
   */
  public DatasetMetaDataGroup() {
    super("METADATA");
  }

  /**
   * Sets some meta data.
   * @param metadataKey    a key for the meta data object
   * @param metadataObject the meta data
   */
  public void setMetaData(String metadataKey, Object metadataObject) {
    metadata.put(metadataKey, metadataObject);
  }
  
  /**
   * Returns some meta data.
   * @param metadataKey  the key of the meta data
   */
  public Object getMetaData(String metadataKey) {
    return metadata.get(metadataKey);
  }

}
