/*******************************************************************************
 * Copyright (c) 2009 Martin O. J. Schmitz.
 * 
 * This file is part of the SCHMITZM library - a collection of utility 
 * classes based on Java 1.6, focusing (not only) on Java Swing 
 * and the Geotools library.
 * 
 * The SCHMITZM project is hosted at:
 * http://wald.intevation.org/projects/schmitzm/
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 3
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License (license.txt)
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 * or try this link: http://www.gnu.org/licenses/lgpl.html
 * 
 * Contributors:
 *     Martin O. J. Schmitz - initial API and implementation
 *     Stefan A. Krüger - additional utility classes
 ******************************************************************************/
package schmitzm.jfree.chart.renderer;

import java.awt.Paint;

import schmitzm.jfree.chart.selection.DatasetSelectionModel;
import schmitzm.jfree.chart.selection.DatasetSelectionModelProvider;

/**
 * This interface defines methods for all chart renderer which differ
 * between selected and unselected data. Selected data is rendered in
 * a highlighted way. 
 * @author <a href="mailto:martin.schmitz@koeln.de">Martin Schmitz</a> (University of Bonn/Germany)
 */
public interface SelectionRenderer<E extends DatasetSelectionModel<?,?,?>> extends DatasetSelectionModelProvider<E>{
  /**
   * Returns the color, the selected data is rendered with.
   */
  public Paint getSelectionPaint();
  /**
   * Returns the color, the selected data is outlined with.
   */
  public Paint getSelectionOutlinePaint();

  /**
   * Sets the color, the selected data is rendered with.
   * @param paint color for the selected data
   */
  public void setSelectionPaint(Paint paint);
  
  /**
   * Sets the color, the selected data is outlined with.
   * @param paint color for the selected data
   */
  public void setSelectionOutlinePaint(Paint paint);

//  /**
//   * Returns the {@link Stroke}, the selected data is rendered with.
//   * @return {@code null} if no special stroke is set (the base stroke
//   *         should be used)
//   */
//  public Stroke getSelectionStroke();
//
//  /**
//   * Sets the {@link Stroke}, the selected data is rendered with.
//   * @param stroke {@link Stroke} for the selected data (set to {@code null}
//   *               if the base stroke should be used)
//   */
//  public void setSelectionStroke(Stroke stroke);
}
