/*******************************************************************************
 * Copyright (c) 2009 Martin O. J. Schmitz.
 * 
 * This file is part of the SCHMITZM library - a collection of utility 
 * classes based on Java 1.6, focusing (not only) on Java Swing 
 * and the Geotools library.
 * 
 * The SCHMITZM project is hosted at:
 * http://wald.intevation.org/projects/schmitzm/
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 3
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License (license.txt)
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 * or try this link: http://www.gnu.org/licenses/lgpl.html
 * 
 * Contributors:
 *     Martin O. J. Schmitz - initial API and implementation
 *     Stefan A. Krüger - additional utility classes
 ******************************************************************************/
package schmitzm.jfree.chart.selection;

import java.util.Set;

import org.jfree.data.general.Dataset;
import org.jfree.data.general.DatasetChangeEvent;
import org.jfree.data.general.SeriesDataset;

/**
 * This selection model maintains whether items of a {@link SeriesDataset} are selected
 * in a chart or not.
 * Any item in this model is identified by its dataset series ({@link Comparable}) and
 * its <b>index</b> in the series ({@link Integer}). 
 * @author <a href="mailto:Martin.Schmitz@koeln.de">Martin Schmitz</a> (University of Bonn/Germany)
 */
public class SeriesDatasetSelectionModel extends AbstractDatasetSelectionModel<SeriesDataset, Comparable<?>, Integer> {
  /**
   * Creates a new selection model.
   * @param dataset {@link Dataset} whose data can be selected
   */
  public SeriesDatasetSelectionModel(SeriesDataset dataset) {
    super(dataset);
  }

  /**
   * Listens for dataset changes. If a series is no longer present
   * in the dataset, the respective items are removed from selection
   * list.
   */
  @Override
  public void datasetChanged(DatasetChangeEvent event) {
    if ( event.getDataset() != this.dataset ||
         !(event.getDataset() instanceof SeriesDataset) )
      return;
    SeriesDataset changedDataset = (SeriesDataset)event.getDataset();
      
    // check whether all series are still present
    for (Comparable<?> seriesKey : selectedSeriesIdx.keySet())
      // if series is no longer present, also remove series
      // from selection model
      if ( changedDataset.indexOf(seriesKey) < 0 ) {
        // clear series set and remove series set
        Set<Integer> selectedIdx = selectedSeriesIdx.get(seriesKey);
        if ( selectedIdx != null )
          selectedIdx.clear();
        selectedSeriesIdx.remove(seriesKey);
      }
  }

}
