/*******************************************************************************
 * Copyright (c) 2009 Martin O. J. Schmitz.
 * 
 * This file is part of the SCHMITZM library - a collection of utility 
 * classes based on Java 1.6, focusing (not only) on Java Swing 
 * and the Geotools library.
 * 
 * The SCHMITZM project is hosted at:
 * http://wald.intevation.org/projects/schmitzm/
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 3
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License (license.txt)
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 * or try this link: http://www.gnu.org/licenses/lgpl.html
 * 
 * Contributors:
 *     Martin O. J. Schmitz - initial API and implementation
 *     Stefan A. Krüger - additional utility classes
 ******************************************************************************/
package schmitzm.jfree.chart.style;

import java.io.IOException;
import java.net.URL;

import org.jdom.Document;
import org.jdom.JDOMException;
import org.jdom.input.SAXBuilder;

import schmitzm.io.IOUtil;

/**
 * This class contains static utility methods related to chart styling.
 * 
 * @author <a href="mailto:Martin.Schmitz@koeln.de">Martin Schmitz</a>
 * @version 1.0
 */
public class ChartStyleUtil {
	private static final SAXBuilder SAX_BUILDER = new SAXBuilder();

	/** Instance of {@link ChartStyleXMLFactory}. */
	public static final ChartStyleXMLFactory CHART_STYLE_FACTORY = new ChartStyleXMLFactory();

	/**
	 * Returns the chart style for a given string.
	 */
	public static ChartType getChartType(String typeStr) {
		try {
			return ChartType.valueOf(typeStr.toUpperCase());
		} catch (IllegalArgumentException err) {
			throw new UnsupportedOperationException(
					"Unknown chart style type: " + typeStr);
		}
	}

	/**
	 * Reads a chart definition from {@link URL}. The URL must refers to a
	 * resource which contains exactly one chart definition as root element.<br>
	 * <b>The filename is taken as chart ID</b>
	 * 
	 * @param url
	 *            refers to XML resource
	 */
	public static ChartStyle readStyleFromXML(URL url,
			ChartStyleXMLFactory factory) throws IOException {
		String id = IOUtil.urlToFile(url).getName();
		return readStyleFromXML(url, id, factory);
	}

	/**
	 * Reads a chart definition from {@link URL}. The URL must refers to a
	 * resource which contains exactly one chart definition as root element.
	 * 
	 * @param url
	 *            refers to XML resource
	 * @param id
	 *            the ID for the style (if {@code null} the ID is taken from
	 *            "id" attribute)
	 * @param factory
	 *            factory to create the style with
	 */
	public static ChartStyle readStyleFromXML(URL url, String id,
			ChartStyleXMLFactory factory) throws IOException {
		try {
			Document document = SAX_BUILDER.build(url);
			return (factory.createStyleFromXML(document.getRootElement(), null));
		} catch (JDOMException err) {
			throw new IOException(err);
		}
	}


}
