/*******************************************************************************
 * Copyright (c) 2009 Martin O. J. Schmitz.
 * 
 * This file is part of the SCHMITZM library - a collection of utility 
 * classes based on Java 1.6, focusing (not only) on Java Swing 
 * and the Geotools library.
 * 
 * The SCHMITZM project is hosted at:
 * http://wald.intevation.org/projects/schmitzm/
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 3
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License (license.txt)
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 * or try this link: http://www.gnu.org/licenses/lgpl.html
 * 
 * Contributors:
 *     Martin O. J. Schmitz - initial API and implementation
 *     Stefan A. Krüger - additional utility classes
 ******************************************************************************/
package schmitzm.jfree.feature;

import org.geotools.feature.FeatureCollection;
import org.jfree.data.general.SeriesDataset;
import org.opengis.feature.simple.SimpleFeature;

/**
 * This class implements the mapping between {@link SeriesDataset} items (points in chart)
 * and the corresponding {@link SimpleFeature Features}.
 * The structure of this mapping assumes that there can be multiple
 * dataset items for one feature (e.g. in each series), but only one feature
 * for each dataset item.
 * @author <a href="mailto:martin.schmitz@koeln.de">Martin Schmitz</a>
 */
public class Feature2SeriesDatasetMapping extends Feature2DatasetMapping<SeriesDataset,Comparable<?>,Integer> {
//  /** Holds the data items ({@code Map<SeriesKey,ItemIndex>})
//   *  for each feature ID (String). */
//  protected Map<String,Map<Comparable<?>,Integer>> fid2did = new HashMap<String, Map<Comparable<?>,Integer>>();
//  /** Holds for each series the feature ID (String) for each data item. */
//  protected Map<Comparable<?>,Map<Integer,String>> did2fid = new HashMap<Comparable<?>,Map<Integer,String>>();
  
  /**
   * Creates a mapping. 
   * @param fc a {@link FeatureCollection} (can be {@code null})
   * @param dataset a {@link SeriesDataset} 
   */
  public Feature2SeriesDatasetMapping(FeatureCollection fc, SeriesDataset dataset) {
    super(fc, dataset);
  }

  /**
   * Returns the key of the primary series.
   */
  public Comparable<?> getPrimarySeriesKey() {
    return dataset.getSeriesKey(0);
  }
  
//  /**
//   * Sets the mapping between a feature ID and a dataset item IN THE
//   * PRIMARY SERIES.
//   * @param featureID    feature ID
//   * @param itemID       defines the dataset item
//   */
//  @Override
//  public void setMapping(String featureID, Integer itemID) {
//    setMapping(featureID, null, itemID);
//  }

//  /**
//   * Sets the mapping between a feature ID and a dataset item.
//   * @param featureID    feature ID
//   * @param seriesKey    defines the series of corresponding dataset item (if
//   *                     {@code null} the primary series is used)
//   * @param itemID       defines the dataset item
//   */
//  @Override
//  public void setMapping(String featureID, Comparable<?> seriesKey, Integer itemID) {
//    if ( seriesKey == null )
//      seriesKey = getPrimarySeriesKey();
//    // Mapping FeatureID --> (Series/Index)
//    Map<Comparable<?>,Integer> itemIDs = fid2did.get(featureID);
//    if ( itemIDs == null ) {
//      itemIDs = new HashMap<Comparable<?>, Integer>();
//      fid2did.put(featureID, itemIDs);
//    }
//    itemIDs.put(seriesKey, itemID);
//    
//    // Mapping (Series/Index) --> FeatureID
//    Map<Integer,String> featureIDs = did2fid.get(seriesKey);
//    if ( featureIDs == null ) {
//      featureIDs = new HashMap<Integer, String>();
//      did2fid.put(seriesKey, featureIDs);
//    }
//    featureIDs.put(itemID, featureID);
//  }
  
//  /**
//   * Removes the mapping of a feature ID.
//   * @param fID feature ID
//   */
//  @Override
//  public void removeMappingForFeatureID(String fID) {
//    // remove mapping FeatureID --> (Series/Index)
//    Map<Comparable<?>, Integer> itemIDs = fid2did.remove(fID);
//
//    // remove mapping (Series/Index) --> FeatureID
//    // for all item IDs referencing to the feature ID
//    for (Comparable<?> seriesKey : itemIDs.keySet()) {
//      Map<Integer, String> featureIDs = did2fid.get(seriesKey);
//      for (Integer itemID : itemIDs.values())
//        featureIDs.remove(itemID);
//    }
//  }
  
//  /**
//   * Removes the mapping for a dataset item IN THE
//   * PRIMARY SERIES.
//   * @param itemID    dataset item
//   */
//  public void removeMappingForDataItem(Integer itemID) {
//    removeMappingForDataItem(null,itemID);
//  }

//  /**
//   * Removes the mapping for a dataset item.
//   * @param seriesKey defines the series of the dataset item (if
//   *                  {@code null} the primary series is used)
//   * @param itemID    dataset item
//   */
//  @Override
//  public void removeMappingForDataItem(Comparable<?> seriesKey, Integer itemID) {
//    if ( seriesKey == null )
//      seriesKey = getPrimarySeriesKey();
//    // remove mapping (Series/Index) --> FeatureID 
//    Map<Integer, String> featureIDs = did2fid.get(seriesKey);
//    String fID = null;
//    if ( featureIDs != null )
//      fID = featureIDs.remove(itemID);
//    
//    // remove mapping FeatureID --> (Series/Index)
//    if ( fID != null ) {
//      Map<Comparable<?>, Integer> itemIDs = fid2did.remove(fID);
//      itemIDs.remove(seriesKey);
//    }  
//  }

//  /**
//   * Returns the data items for a given feature IN THE
//   * PRIMARY SERIES.
//   * @param fID a feature ID
//   * @return {@code null} if no data item is registered for the feature ID
//   */
//  public Integer getDataID(String fID) {
//    return getDataID(null,fID);
//  }

//  /**
//   * Returns the data items for a given feature ID.
//   * @param fID a feature ID
//   * @param seriesKey defines the series of the dataset item (if
//   *                  {@code null} the primary series is used)
//   * @return {@code null} if no data item is registered for the feature ID
//   */
//  @Override
//  public Integer getDataID(Comparable<?> seriesKey, String fID) {
//    if ( seriesKey == null )
//      seriesKey = getPrimarySeriesKey();
//    Map<Comparable<?>,Integer> seriesIDs = getDataIDs(fID);
//    if ( seriesIDs != null )
//      return seriesIDs.get(seriesKey);
//    return null;
//  }


//  /**
//   * Returns the data items (of all series) for a given feature ID.
//   * @param fID a feature ID
//   * @return {@code null} if no data item is registered for the feature ID
//   */
//  @Override
//  public Map<Comparable<?>,Integer> getDataIDs(String fID) {
//    return fid2did.get(fID);
//  }
  
//  /**
//   * Returns the feature ID for a given data item IN THE
//   * PRIMARY SERIES.
//   * @param itemID a data item
//   * @return {@code null} if no feature ID is registered for the data item
//   */
//  public String getFeatureID(Integer itemID) {
//    return getFeatureID(null,itemID);
//  }

//  /**
//   * Returns the feature ID for a given data item.
//   * @param seriesKey defines the series of the dataset item  (if
//   *                  {@code null} the primary series is used)
//   * @param itemID a data item
//   * @return {@code null} if no feature ID is registered for the data item
//   */
//  @Override
//  public String getFeatureID(Comparable<?> seriesKey, Integer itemID) {
//    if ( seriesKey == null )
//      seriesKey = getPrimarySeriesKey();
//    Map<Integer,String> featureIDs = did2fid.get(seriesKey);
//    if ( featureIDs != null )
//      return featureIDs.get(itemID); 
//    return null;
//  }
}
