/*******************************************************************************
 * Copyright (c) 2009 Martin O. J. Schmitz.
 * 
 * This file is part of the SCHMITZM library - a collection of utility 
 * classes based on Java 1.6, focusing (not only) on Java Swing 
 * and the Geotools library.
 * 
 * The SCHMITZM project is hosted at:
 * http://wald.intevation.org/projects/schmitzm/
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 3
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License (license.txt)
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 * or try this link: http://www.gnu.org/licenses/lgpl.html
 * 
 * Contributors:
 *     Martin O. J. Schmitz - initial API and implementation
 *     Stefan A. Krüger - additional utility classes
 ******************************************************************************/
package schmitzm.jfree.feature;

import java.util.Set;

import org.jfree.data.general.Dataset;

import schmitzm.jfree.chart.selection.DatasetSelectionModel;

/**
 * This selection model maintains whether items of a {@link Dataset} corresponding
 * to features are selected in a chart or not.
 * @author <a href="mailto:Martin.Schmitz@koeln.de">Martin Schmitz</a> (University of Bonn/Germany)
 */
public interface FeatureDatasetSelectionModel<D extends Dataset, E, F> extends DatasetSelectionModel<D, E, F> {
  /**
   * Checks if the data item of a feature is selected.
   * @param fID  feature ID
   */
  public boolean isFeatureSelected(String fID);
  
  /**
   * Sets whether the data item of a feature is selected or not.
   * @param fID  feature ID
   * @param selected  flag to (de)select the item
   */
  public void setItemSelected(String fID, boolean selected);
  
  /**
   * Changes the selection of the data item of a feature.
   * @param fID  feature ID
   * @return {@code true} if the item changed to selected 
   */
  public boolean changeItemSelection(String fID);
  
  /**
   * Returns the IDs of the selected features.
   */
  public Set<String> getSelectedFeatures();

}
