/*******************************************************************************
 * Copyright (c) 2009 Martin O. J. Schmitz.
 * 
 * This file is part of the SCHMITZM library - a collection of utility 
 * classes based on Java 1.6, focusing (not only) on Java Swing 
 * and the Geotools library.
 * 
 * The SCHMITZM project is hosted at:
 * http://wald.intevation.org/projects/schmitzm/
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 3
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License (license.txt)
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 * or try this link: http://www.gnu.org/licenses/lgpl.html
 * 
 * Contributors:
 *     Martin O. J. Schmitz - initial API and implementation
 *     Stefan A. Krüger - additional utility classes
 ******************************************************************************/
package schmitzm.lang;

/**
 * Diese Exception stellt einen Duplikat-Fehler dar.
 * @author <a href="mailto:martin.schmitz@koeln.de">Martin Schmitz</a> (University of Bonn/Germany)
 * @version 1.0
 */
public class DuplicateException extends RuntimeException {
  private Object currObj = null;
  private Object duplObj = null;

  /**
   * Erzeugt eine neue Exception
   * @param mess    Fehlerbeschreibung
   * @param currObj das bestehende Objekt
   * @param duplObj das Duplikat, das den Fehler ausgeloest hat
   */
  public DuplicateException(String mess, Object currObj, Object duplObj) {
    super(mess);
    this.currObj = currObj;
    this.duplObj = duplObj;
  }

  /**
   * Erzeugt eine neue Exception
   * @param mess    Fehlerbeschreibung
   */
  public DuplicateException(String mess) {
    this(mess, null, null);
  }

  /**
   * Erzeugt eine neue Exception
   */
  public DuplicateException() {
    this("", null, null);
  }

  /**
   * Liefert das bestehende Objekt.
   * @return Object
   */
  public Object getCurrentObject() {
    return this.currObj;
  }

  /**
   * Liefert das Objekt, das den Duplikatfehler ausgeloest hat.
   */
  public Object getDuplicateObject() {
    return this.duplObj;
  }

}
