/*******************************************************************************
 * Copyright (c) 2009 Martin O. J. Schmitz.
 * 
 * This file is part of the SCHMITZM library - a collection of utility 
 * classes based on Java 1.6, focusing (not only) on Java Swing 
 * and the Geotools library.
 * 
 * The SCHMITZM project is hosted at:
 * http://wald.intevation.org/projects/schmitzm/
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 3
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License (license.txt)
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 * or try this link: http://www.gnu.org/licenses/lgpl.html
 * 
 * Contributors:
 *     Martin O. J. Schmitz - initial API and implementation
 *     Stefan A. Krüger - additional utility classes
 ******************************************************************************/
package schmitzm.lang;

/**
 * Diese Klasse stellt eine Hilfsklasse fuer eingerueckte Texte dar.
 * Mittels der Methoden {@link #push()} und {@link #pop()} wird die Einrueckung
 * um ein feste Anzahl an Leerstellen erweitert bzw. reduziert.
 * @author <a href="mailto:martin.schmitz@koeln.de">Martin Schmitz</a> (University of Bonn/Germany)
 * @version 1.0
 */
public class Indent {
  private StringBuffer buffer = new StringBuffer();
  private String       indent = null;

  /**
   * Erzeugt eine neue Einrueckung fuer 2 Stellen.
   */
  public Indent() {
    this(2);
  }

  /**
   * Erzeugt eine neue Einrueckung.
   * @param len Anzahl der Stellen, um die eingerueckt wird.
   */
  public Indent(int len) {
    indent = "";
    for (int i=0; i<len; i++)
      indent += "";
  }

  /**
   * Loescht den Einrueck-Buffer.
   */
  public void clear() {
    buffer = new StringBuffer();
  }

  /**
   * Liefert die aktuelle Anzahl an Leerstellen, um die eingerueckt wird.
   */
  public int getLength() {
    return buffer.length();
  }

  /**
   * Liefert die Leerstellen, um die bei einem {@link #push()}-Aufruf
   * eingerueckt wird.
   */
  public String getIndent() {
    return indent;
  }

  /**
   * Liefert die Anzahl an Leerstellen, um die bei einem {@link #push()}-Aufruf
   * eingerueckt wird.
   */
  public int getIndentLength() {
    return indent.length();
  }


  /**
   * Erweitert die Einrueckung um die im Konstruktor angegebene Anzahl an
   * Leerstellen.
   * @see #getIndent()
   * @see #getIndentLength()
   */
  public void push() {
    buffer.append(indent);
  }

  /**
   * Reduziert die Einrueckung um die im Konstruktor angegebene Anzahl an
   * Leerstellen.
   * @see #getIndent()
   * @see #getIndentLength()
   */
  public void pop() {
    buffer.delete( buffer.length()-indent.length(), buffer.length() );
  }

  /**
   * Liefert die aktuelle Einrueckung als String.
   */
  public String toString() {
    return buffer.toString();
  }
}
