/*******************************************************************************
 * Copyright (c) 2009 Martin O. J. Schmitz.
 * 
 * This file is part of the SCHMITZM library - a collection of utility 
 * classes based on Java 1.6, focusing (not only) on Java Swing 
 * and the Geotools library.
 * 
 * The SCHMITZM project is hosted at:
 * http://wald.intevation.org/projects/schmitzm/
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 3
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License (license.txt)
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 * or try this link: http://www.gnu.org/licenses/lgpl.html
 * 
 * Contributors:
 *     Martin O. J. Schmitz - initial API and implementation
 *     Stefan A. Krüger - additional utility classes
 ******************************************************************************/
package schmitzm.lang;

import java.util.Comparator;
import java.util.Locale;

/**
 * {@code Comparator} um {@link Locale Locales} zu vergleichen. Es kann nach
 * der Beschreibung (in der aktuellen Default-Locale) verglichen werden oder
 * nach dem Sprach-Code.
 * @author <a href="mailto:Martin.Schmitz@koeln.de">Martin Schmitz</a> (University of Bonn/Germany)
 * @version 1.0
 */
public class LocaleComparator implements Comparator<Locale> {
  /** Flag, ob nach der {@linkplain Locale#getDisplayName() Beschreibung}
   *  verglichen wird ({@code true}) oder nach dem
   *  {@linkplain Locale#toString() Sprach-Code}. */
  protected boolean compareDesc = false;

  /**
   * Erzeugt einen neuen {@code Comparator}.
   * @param compareDesc Flag, ob nach der {@linkplain Locale#getDisplayName() Beschreibung}
   *                    verglichen wird ({@code true}) oder nach dem
   *                    {@linkplain Locale#toString() Sprach-Code}.
   */
  public LocaleComparator(boolean compareDesc) {
    this.compareDesc = compareDesc;
  }

  /**
   * Fuehrt den Vergleich aus.
   * @param loc1 eine Locale
   * @param loc2 eine andere Locale
   * @return ein negativer Wert fuer {@code loc1 < loc2}, 0 für {@code loc1 = loc2}
   *         oder ein positiver Wert fuer {@code loc1 > loc2}
   */
  public int compare(Locale loc1, Locale loc2) {
    if ( compareDesc )
      return loc1.getDisplayName().compareTo(loc2.getDisplayName());
    return loc1.toString().compareTo(loc2.toString());
  }
}
