/*******************************************************************************
 * Copyright (c) 2009 Martin O. J. Schmitz.
 * 
 * This file is part of the SCHMITZM library - a collection of utility 
 * classes based on Java 1.6, focusing (not only) on Java Swing 
 * and the Geotools library.
 * 
 * The SCHMITZM project is hosted at:
 * http://wald.intevation.org/projects/schmitzm/
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 3
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License (license.txt)
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 * or try this link: http://www.gnu.org/licenses/lgpl.html
 * 
 * Contributors:
 *     Martin O. J. Schmitz - initial API and implementation
 *     Stefan A. Krüger - additional utility classes
 ******************************************************************************/
package schmitzm.swing;

import javax.swing.AbstractButton;
import javax.swing.ButtonModel;
import javax.swing.JRadioButton;

/**
 * Diese Klasse erweitert die {@link javax.swing.ButtonGroup javax.swing.ButtonGroup}
 * um die Option, alle Button der Gruppe wieder zu deaktivieren. Dies geschieht,
 * in dem immer ein "unsichtbarer" Dummy-Button Bestandteil der Gruppe ist,
 * der aktiviert wird, wenn alle anderen Butten deaktiviert sein sollen.
 * @author <a href="mailto:martin.schmitz@koeln.de">Martin Schmitz</a> (University of Bonn/Germany)
 * @version 1.0
 */
public class ButtonGroup extends javax.swing.ButtonGroup {
  private JRadioButton deactivationButton = new JRadioButton();

  /**
   * Erzeugt eine neue Button-Gruppe.
   */
  public ButtonGroup() {
    super();
    this.add(deactivationButton);
  }

  /**
   * Deaktiviert alle Button der Gruppe.
   */
  public void setUnselected() {
    deactivationButton.setSelected(true);
  }

//  /**
//   * Liefert die Anzahl der Button innerhalb der Gruppe. Der Dummy-Button wird
//   * dabei nicht mit gerechnet!
//   */
//  public int getButtonCount() {
//    return super.getButtonCount()-1;
//  }

  /**
   * Prueft, ob irgendein Button der Gruppe aktiviert ist. Der Dummy-Button wird
   * dabei nicht beruecksichtigt!
   */
  public boolean isSelected(ButtonModel model) {
    return super.isSelected(model) && !deactivationButton.isSelected();
  }

  /**
   * Liefert den Button der Gruppe, der selektiert ist. Der Dummy-Button wird
   * dabei nicht beruecksichtigt!
   * @return <code>null</code> wenn kein Button selektiert ist
   */
  public AbstractButton getSelectedButton() {
    for (int i=0; i<this.buttons.size(); i++) {
      AbstractButton button = buttons.elementAt(i);
      if ( button.isSelected() && button != deactivationButton )
        return buttons.elementAt(i);
    }
    return null;
  }
}
