/*******************************************************************************
 * Copyright (c) 2009 Martin O. J. Schmitz.
 * 
 * This file is part of the SCHMITZM library - a collection of utility 
 * classes based on Java 1.6, focusing (not only) on Java Swing 
 * and the Geotools library.
 * 
 * The SCHMITZM project is hosted at:
 * http://wald.intevation.org/projects/schmitzm/
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 3
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License (license.txt)
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 * or try this link: http://www.gnu.org/licenses/lgpl.html
 * 
 * Contributors:
 *     Martin O. J. Schmitz - initial API and implementation
 *     Stefan A. Krüger - additional utility classes
 ******************************************************************************/
package schmitzm.swing;

import java.util.Map;

import javax.swing.JPanel;

/**
 * Dieses Interface ermoeglicht es die Beschriftungen in einer Swing-Komponente
 * (Labels und Buttons) nachtraeglich zu aendern. Zum Beispiel, wenn in einer
 * uebergeordneten Anwendung die Sprache gewechselt wird.<br>
 * Beim Aufruf von {@link #resetCaptions(Map)} muss die Komponente, welche
 * {@code CaptionsChangeable} implmentiert, gewaehrleisten, dass alle Beschriftungen
 * entsprechend der uebergebenen {@link Map} geaendert werden. Hierfuer sollte die
 * {@code CaptionsChangeable}-Komponente eindeutige Key-Konstanten implementieren,
 * ueber die die uebergeordnete Anwendung die neuen Beschriftungen in der Map
 * hinterlegen kann.<br>
 * Zudem sollte eine {@code CaptionsChangeable}-Komponente den {@link #resetCaptions(Map)}-Aufruf
 * an alle in ihr enthaltenen {@code CaptionsChangeable}-Komponenten weiterleiten.
 * {@link CaptionsChangeablePanel} stellt ein ansonsten normales {@link JPanel}
 * dar, welches diese Funktionalitaet bereits implementiert.
 * @author <a href="mailto:martin.schmitz@koeln.de">Martin Schmitz</a> (University of
 *   Bonn/Germany)
 * @version 1.0
 */
public interface CaptionsChangeable {
  /**
   * Aktualisiert alle Beschriftungen der Komponente entsprechend der uebergebenen
   * Map.
   * @param captionMap enthaelt die neuen Beschriftungen
   */
  public void resetCaptions(Map<String, Object> captionMap);
}
