/*******************************************************************************
 * Copyright (c) 2009 Martin O. J. Schmitz.
 * 
 * This file is part of the SCHMITZM library - a collection of utility 
 * classes based on Java 1.6, focusing (not only) on Java Swing 
 * and the Geotools library.
 * 
 * The SCHMITZM project is hosted at:
 * http://wald.intevation.org/projects/schmitzm/
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 3
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License (license.txt)
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 * or try this link: http://www.gnu.org/licenses/lgpl.html
 * 
 * Contributors:
 *     Martin O. J. Schmitz - initial API and implementation
 *     Stefan A. Krüger - additional utility classes
 ******************************************************************************/
package schmitzm.swing;

import java.awt.Color;
import java.awt.Component;
import java.awt.Graphics;

import javax.swing.Icon;

/**
 * Diese Klasse stellt ein Icon in Form eines ausgefuellten Kreises
 * dar.
 * @author <a href="mailto:martin.schmitz@koeln.de">Martin Schmitz</a> (University of Bonn/Germany)
 * @version 1.0
 */
public class CircleIcon implements Icon
{
    private int   width;
    private int   height;
    private Color color;

    /**
     * Erzeugt ein Icon mit einem ausgefuellten Kreis.
     * @param width Breite des Kreises
     * @param height Hoehe des Kreises
     * @param color Farbe des Kreises
     */
    public CircleIcon(int width, int height, Color color)
    {
        this.width  = width;
        this.height = height;
        this.color  = color;
    }

    /**
     * Malt den Kreis an die angegeben Stelle (x,y) in das Graphics-
     * Objekt.
     */
    public void paintIcon(Component c, Graphics g, int x, int y)
    {
        g.setColor(color);
        g.fillOval(x,y,width,height);
    }

    /**
     * Liefert die Hoehe des Kreises.
     * @return Hoehe des Kreises in Pixeln
     */
    public int getIconHeight()
    {
        return height;
    }

    /**
     * Liefert die Breite des Kreises.
     * @return Breite des Kreises in Pixeln
     */
    public int getIconWidth()
    {
        return width;
    }
}
