/*******************************************************************************
 * Copyright (c) 2009 Martin O. J. Schmitz.
 * 
 * This file is part of the SCHMITZM library - a collection of utility 
 * classes based on Java 1.6, focusing (not only) on Java Swing 
 * and the Geotools library.
 * 
 * The SCHMITZM project is hosted at:
 * http://wald.intevation.org/projects/schmitzm/
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 3
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License (license.txt)
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 * or try this link: http://www.gnu.org/licenses/lgpl.html
 * 
 * Contributors:
 *     Martin O. J. Schmitz - initial API and implementation
 *     Stefan A. Krüger - additional utility classes
 ******************************************************************************/
package schmitzm.swing;

import java.io.OutputStream;
import java.io.PrintStream;

import javax.swing.JTextArea;

/**
 * Diese Klasse stellt einen {@link PrintStream} dar, der an eine {@link JTextArea}
 * gekoppelt ist. Jegliche Ausgabe, die auf den Stream geschrieben wird, wird
 * in der TextArea ausgegeben
 * @author <a href="mailto:martin.schmitz@koeln.de">Martin Schmitz</a> (University of Bonn/Germany)
 * @version 1.0
 */
public class TextAreaPrintStream extends PrintStream {
  /**
   * Erzeugt einen neuen Stream.
   * @param textArea Ausgabe-Komponente
   */
  public TextAreaPrintStream(final JTextArea textArea) {
    super(new OutputStream() {
      public void write(int b) {
        textArea.append( String.valueOf((char)b) );
        // Position ans Ende des Textes setzen
        textArea.setCaretPosition( textArea.getText().lastIndexOf("\n")+1 );
      }
    } );
  }
}
