/*******************************************************************************
 * Copyright (c) 2009 Martin O. J. Schmitz.
 * 
 * This file is part of the SCHMITZM library - a collection of utility 
 * classes based on Java 1.6, focusing (not only) on Java Swing 
 * and the Geotools library.
 * 
 * The SCHMITZM project is hosted at:
 * http://wald.intevation.org/projects/schmitzm/
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 3
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License (license.txt)
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 * or try this link: http://www.gnu.org/licenses/lgpl.html
 * 
 * Contributors:
 *     Martin O. J. Schmitz - initial API and implementation
 *     Stefan A. Krüger - additional utility classes
 ******************************************************************************/
package schmitzm.swing;

import java.awt.Component;
import java.awt.Dimension;

import javax.swing.JButton;
import javax.swing.JDialog;
import javax.swing.JOptionPane;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.JTree;
import javax.swing.event.TreeSelectionEvent;
import javax.swing.event.TreeSelectionListener;
import javax.swing.tree.DefaultMutableTreeNode;
import javax.swing.tree.TreeModel;
import javax.swing.tree.TreePath;
import javax.swing.tree.TreeSelectionModel;

/**
 * Diese Klasse stellt einen Dialog dar, der Objekte in einer Baumstruktur zur
 * Auswahl stellt.
 * @author <a href="mailto:martin.schmitz@koeln.de">Martin Schmitz</a> (University of Bonn/Germany)
 * @version 1.0
 */
public class TreeSelectionDialog extends JOptionPane {
  private TreeModel           model = null;
  private JTree               tree  = null;
  private TreeSelectionDialog THIS  = this;

  /**
   * Erzeugt einen neuen Dialog.
   * @param model Daten-Basis fuer die darzustellenden Objekte
   */
  public TreeSelectionDialog(TreeModel model) {
    super();
    this.setPreferredSize(new Dimension(250,300));
    this.validate();
    this.model = model;
    this.tree  = new JTree(model);
    tree.setRootVisible(false);
    this.setOptionType(JOptionPane.OK_CANCEL_OPTION);
    this.setMessage( new JScrollPane(tree) );
    // OK-Button soll nur aktiviert sein, wenn ein passendes Objekt
    // ausgewaehlt ist
    final JButton okButton = (JButton)((JPanel)THIS.getComponent(1)).getComponent(0);
    okButton.setEnabled(false);
    this.tree.addTreeSelectionListener( new TreeSelectionListener() {
      public void valueChanged(TreeSelectionEvent e) {
        okButton.setEnabled(
            e.getNewLeadSelectionPath() != null &&
            e.getNewLeadSelectionPath().getLastPathComponent() != null &&
            e.getNewLeadSelectionPath().getLastPathComponent() instanceof DefaultMutableTreeNode &&
            ((DefaultMutableTreeNode)e.getNewLeadSelectionPath().getLastPathComponent()).getUserObject() != null
        );
      }
    });
  }

  /**
   * Zeigt den Auswahldialog an.
   * @param parent aufrufende Komponente
   * @param title Titel fuer das Dialogfenster
   * @param multipleSelect bestimmt, ob mehrere Baum-Elemente (Objekte) gleichzeitig
   *        ausgewaehlt werden duerfen
   * @return alle ausgewaehlten Objekte oder <code>null</code>, wenn der Dialog
   *         abgebrochen wurde.
   */
  public Object[] show(Component parent, String title, boolean multipleSelect) {
    if ( multipleSelect )
      tree.getSelectionModel().setSelectionMode( TreeSelectionModel.DISCONTIGUOUS_TREE_SELECTION );
    else
      tree.getSelectionModel().setSelectionMode( TreeSelectionModel.SINGLE_TREE_SELECTION );

    JDialog dialog = this.createDialog(parent,title);
    dialog.setVisible(true);
    // Dialog abgebrochen
    if ( getValue() == null || ((Integer)getValue() != JOptionPane.OK_OPTION) )
      return null;
    // Dialog mit OK beendet
    TreePath[] selPath = tree.getSelectionPaths();
    Object[]   selObj = new Object[selPath.length];
    for (int i=0; i<selObj.length; i++)
      selObj[i] = ((DefaultMutableTreeNode)selPath[i].getLastPathComponent()).getUserObject();
    return selObj;
  }
}
