/*******************************************************************************
 * Copyright (c) 2009 Martin O. J. Schmitz.
 * 
 * This file is part of the SCHMITZM library - a collection of utility 
 * classes based on Java 1.6, focusing (not only) on Java Swing 
 * and the Geotools library.
 * 
 * The SCHMITZM project is hosted at:
 * http://wald.intevation.org/projects/schmitzm/
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 3
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License (license.txt)
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 * or try this link: http://www.gnu.org/licenses/lgpl.html
 * 
 * Contributors:
 *     Martin O. J. Schmitz - initial API and implementation
 *     Stefan A. Krüger - additional utility classes
 ******************************************************************************/
package schmitzm.swing.event;

import schmitzm.swing.InputOption;

/**
 * Dieser Listener verfolgt die Eingaben in einer {@link schmitzm.swing.InputOption}.
 * @author <a href="mailto:martin.schmitz@koeln.de">Martin Schmitz</a> (University of Bonn/Germany)
 * @version 1.0
 */
public interface InputOptionListener {
  /**
   * Wird aufgerufen, wenn sich der Eingabewert des Option geaendert hat.
   * @param inputOption Option, die sich geaendert hat
   * @param oldValue alter Wert
   * @param newValue neuer Wert
   */
  public <E> void optionChanged(InputOption<E> inputOption, E oldValue, E newValue);

  /**
   * Wird aufgerufen, wenn die Eingabe-Komponente der Option den Fokus
   * erhaelt.
   * @param inputOption Option, die den Focus erhalten hat
   */
  public <E> void optionGainedFocus(InputOption<E> inputOption);

  /**
   * Wird aufgerufen, wenn die Eingabe-Komponente der Option den Fokus
   * verliert.
   * @param inputOption Option, die den Focus verloren hat
   */
  public <E> void optionLostFocus(InputOption<E> inputOption);
}
