/*******************************************************************************
 * Copyright (c) 2009 Martin O. J. Schmitz.
 * 
 * This file is part of the SCHMITZM library - a collection of utility 
 * classes based on Java 1.6, focusing (not only) on Java Swing 
 * and the Geotools library.
 * 
 * The SCHMITZM project is hosted at:
 * http://wald.intevation.org/projects/schmitzm/
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 3
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License (license.txt)
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 * or try this link: http://www.gnu.org/licenses/lgpl.html
 * 
 * Contributors:
 *     Martin O. J. Schmitz - initial API and implementation
 *     Stefan A. Krüger - additional utility classes
 ******************************************************************************/
package schmitzm.swing.menu;

/**
 * Diese Klasse repraesentiert eine Kette von Aktionen. Jede Aktion wird
 * durch einen <code>int</code>-Wert codiert. Alle Aktionen der Kette zusammen
 * muessen ebenfalls in einem <code>int</code>-Wert codiert werden koennen.
 * Eine Moeglichkeit ist z.B. die logische Veroderung der einzelnen Aktionen, wenn
 * jede Einzelaktion durch eine 2er-Potenz codiert wird.
 * @author <a href="mailto:martin.schmitz@koeln.de">Martin Schmitz</a> (University of Bonn/Germany)
 * @version 1.0
 */
public interface ActionStructure {

  /**
   * Aktion, die fuer "keine Aktion" steht.
   */
  public static final int ACTION_NONE = 0;

  /**
   * Liefert das <code>ActionStructure</code>-Element, das in der
   * Kette unmittelbar uebergeordnet ist.
   * @return <code>null</code> falls die Aktion die Wurzel-Aktion darstellt
   */
  public ActionStructure getParentActionStructure();

  /**
   * Liefert die Aktion, fuer die dieses Element in der
   * <code>ActionStructure</code>-Kette steht.
   */
  public int getActionCode();

  /**
   * Liefert einen Wert, der saemtliche Aktionen der
   * <code>ActionStructure</code>-Kette codiert. z.B. logische Veroderung der
   * einzelnen Aktionen der <code>ActionStructure</code>-Kette.
   */
  public int getCompleteActionCode();

  /**
   * Prueft, ob zwei Actionscodes gemeinsame Komponenten beinhalten.
   * @param actionCode1 Aktionscode
   * @param actionCode2 Aktionscode
   * @return <code>true</code> gdw. die beiden Gesamt-Aktionen mindestens
   *         eine gemeinsame Aktion haben.
   */
  public boolean compareActions(int actionCode1, int actionCode2);
}
