/*******************************************************************************
 * Copyright (c) 2009 Martin O. J. Schmitz.
 * 
 * This file is part of the SCHMITZM library - a collection of utility 
 * classes based on Java 1.6, focusing (not only) on Java Swing 
 * and the Geotools library.
 * 
 * The SCHMITZM project is hosted at:
 * http://wald.intevation.org/projects/schmitzm/
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 3
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License (license.txt)
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 * or try this link: http://www.gnu.org/licenses/lgpl.html
 * 
 * Contributors:
 *     Martin O. J. Schmitz - initial API and implementation
 *     Stefan A. Krüger - additional utility classes
 ******************************************************************************/
package schmitzm.swing.table;

/**
 * Erweitert das Java {@link javax.swing.table.AbstractTableModel} in dem die
 * Methoden {@code #getColumnName(int)} und {@link #getColumnCount()} bereits
 * implementiert sind. Diese werden durch die neue abstrakte Methode
 * {@link #createColumnNames()} bestimmt.
 * @author <a href="mailto:martin.schmitz@koeln.de">Martin Schmitz</a> (University of Bonn/Germany)
 *
 */
public abstract class AbstractTableModel extends javax.swing.table.AbstractTableModel {

  /** Beinhaltet die Spaltennamen.
   *  @see #createColumnNames() */
  protected String[] colNames = createColumnNames();

  /**
   * Liefert die Anzahl an Spalten.
   * @param col Spaltenindex (beginnend bei 0)
   */
  public int getColumnCount() {
    return colNames.length;
  }

  /**
   * Liefert den Namen einer Spalte.
   * @param col Spaltenindex (beginnend bei 0)
   */
  @Override
  public String getColumnName(int col) {
    return colNames[col];
  }

  /**
   * Liefert die Spaltennamen der Tabelle. Diese Methode liefert direkten
   * Zugriff auf den Array der Spaltennamen, so dass dessen Inhalt veraendert
   * werden kann (z.B. fuer Internationalisierung).
   */
  public String[] getColumnNames()  {
    return colNames;
  }

  /**
   * Erzeugt die Spaltennamen der Tabelle.
   */
  public abstract String[] createColumnNames();

}
