/*******************************************************************************
 * Copyright (c) 2009 Martin O. J. Schmitz.
 * 
 * This file is part of the SCHMITZM library - a collection of utility 
 * classes based on Java 1.6, focusing (not only) on Java Swing 
 * and the Geotools library.
 * 
 * The SCHMITZM project is hosted at:
 * http://wald.intevation.org/projects/schmitzm/
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 3
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License (license.txt)
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 * or try this link: http://www.gnu.org/licenses/lgpl.html
 * 
 * Contributors:
 *     Martin O. J. Schmitz - initial API and implementation
 *     Stefan A. Krüger - additional utility classes
 ******************************************************************************/
package schmitzm.swing.table;

import javax.swing.JTable;
import javax.swing.table.TableModel;

/**
 * Diese Klasse erweitert das {@link TableModel} um die 3
 * Aktionen
 * <ul>
 * <li>Hinzufuegen einer Tabellenzeile</li>
 * <li>Loeschen einer Tabellenzeile</li>
 * <li>Aendern einer Tabellenzelle</li>
 * </ul>
 * Diese Aktionsaufforderungen koennen somit von ausserhalb (z.B. durch ein Menue)
 * an das TableModel herangetragen werden.
 * @see MutableTable
 * @author <a href="mailto:martin.schmitz@koeln.de">Martin Schmitz</a> (University of Bonn/Germany)
 * @version 1.0
 */
public interface MutableTableModel extends TableModel {
  /**
   * Fordert das TableModel auf, eine bestimmte Zeile zu loeschen.
   * @param row Zeilennummer
   */
  public void performRemoveRow(int row);

  /**
   * Fordert das TableModel auf, eine Zeile hinzuzufuegen. Das TableModel ist
   * dafuer verwantwortlich, die benoetigten Daten zu ermitteln (z.B. ueber
   * einen Anwender-Dialog).
   */
  public void performAddRow();

  /**
   * Fordert das TableModel auf, eine Tabellenzelle zu aendern. Das TableModel ist
   * dafuer verwantwortlich, die benoetigten Daten zu ermitteln (z.B. ueber
   * einen Anwender-Dialog).
   * @param row Zeilennummer
   * @param col Spalzennummer
   */
  public void performChangeData(int row, int col);

  /**
   * Initiert ein Neu-Aufbauen der Tabelle.
   */
  public void fireTableDataChanged();

  /**
   * Wird von {@link MutableTable#setModel(TableModel)}
   * aufgerufen. Bietet die Moeglichkeit, Tabellenmodell-spezifische
   * Eigenschaften an der darstellenden Tabelle automatisch durch
   * das Tabellenmodell zu setzen.
   * @param table Tabelle, in der das {@link TableModel} dargestellt wird
   */
  public void initTable(JTable table);

}
