/*******************************************************************************
 * Copyright (c) 2009 Martin O. J. Schmitz.
 * 
 * This file is part of the SCHMITZM library - a collection of utility 
 * classes based on Java 1.6, focusing (not only) on Java Swing 
 * and the Geotools library.
 * 
 * The SCHMITZM project is hosted at:
 * http://wald.intevation.org/projects/schmitzm/
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 3
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License (license.txt)
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 * or try this link: http://www.gnu.org/licenses/lgpl.html
 * 
 * Contributors:
 *     Martin O. J. Schmitz - initial API and implementation
 *     Stefan A. Krüger - additional utility classes
 ******************************************************************************/
package schmitzm.swing.tree;

/**
 * Diese Klasse stellt Knoten dar, ein Objekt beinhaltet. Sie ist als
 * Pondon zu {@link EmptyNode} entworfen, implementiert zur Zeit jedoch
 * nichts anderes, als darauf zu achen, dass das User-Objekt
 * nicht auf <code>null</code> gesetzt wird.
 */
public class ContentNode extends EditableNode {
  private String desc = null;

  /**
   * Erzeugt einen neuen Knoten.
   * @exception java.lang.UnsupportedOperationException falls <code>null</code>
   *            als UserObject angegeben wird
   */
  public ContentNode(Object userObject, boolean editable) {
    this(userObject, null, editable);
  }

  /**
   * Erzeugt einen neuen Knoten.
   * @exception java.lang.UnsupportedOperationException falls <code>null</code>
   *            als UserObject angegeben wird
   */
  public ContentNode(Object userObject, String desc, boolean editable) {
    super(userObject, editable);
    this.desc = desc;
    checkUserObject(userObject);
  }

  /**
   * Setzt das User-Object neu.
   * @exception java.lang.UnsupportedOperationException falls <code>null</code>
   *            als UserObject angegeben wird
   */
  public void setUserObject(Object userObject) {
    checkUserObject(userObject);
    super.setUserObject(userObject);
  }

  /**
   * Prueft ein Objekt auf <code>null</code>.
   * @exception java.lang.UnsupportedOperationException falls <code>null</code>
   *            als UserObject angegeben wird
   */
  private void checkUserObject(Object o) {
    if (o==null)
      throw new UnsupportedOperationException("ContentNode can not contain a null-UserObject!");
  }

  /**
   * Liefert die Beschreibung, die fuer den Knoten angezeigt wird.
   * Ist diese auf <code>null</code> gesetzt, wird die Standard-Bezeichnung
   * <code>super.toString()</code> zurueckgegeben.
   * @return String
   */
  public String toString() {
    return desc != null ? desc : super.toString() ;
  }
}
