/*******************************************************************************
 * Copyright (c) 2009 Martin O. J. Schmitz.
 * 
 * This file is part of the SCHMITZM library - a collection of utility 
 * classes based on Java 1.6, focusing (not only) on Java Swing 
 * and the Geotools library.
 * 
 * The SCHMITZM project is hosted at:
 * http://wald.intevation.org/projects/schmitzm/
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 3
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License (license.txt)
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 * or try this link: http://www.gnu.org/licenses/lgpl.html
 * 
 * Contributors:
 *     Martin O. J. Schmitz - initial API and implementation
 *     Stefan A. Krüger - additional utility classes
 ******************************************************************************/
package schmitzm.swing.tree;

import javax.swing.tree.DefaultMutableTreeNode;

/**
 * Diese Klasse erweitert den {@link javax.swing.tree.DefaultMutableTreeNode} um
 * eine Editierbar?-Eigenschaft.
 */
public class EditableNode extends DefaultMutableTreeNode {
  private boolean editable = false;
  /**
   * Erzeugt einen neuen Knoten. Diesem ist kein
   * Inhalt zugeordnet, er kann aber Kindknoten erhalten.
   */
  public EditableNode(boolean editable) {
    this(null, editable);
  }

  /**
   * Erzeugt einen neuen Knoten. Diesem ist ein
   * Inhalt zugeordnet und er kann Kindknoten erhalten.
   */
  public EditableNode(Object userObject, boolean editable) {
    this(userObject, editable, true);
  }

  /**
   * Erzeugt einen neuen Knoten. Diesem ist ein Inhalt zugeordnet.
   * Ob er Kindknoten erhalten kann haengt vom
   * <code>allowsChildren</code>-Parameter ab.
   */
  public EditableNode(Object userObject, boolean editable, boolean allowsChildren) {
    super(userObject, allowsChildren);
    this.editable = editable;
  }

  /**
   * Prueft, ob der Knoten editierbar ist.
   */
  public boolean isEditable() {
    return this.editable;
  }
}





