/*******************************************************************************
 * Copyright (c) 2009 Martin O. J. Schmitz.
 * 
 * This file is part of the SCHMITZM library - a collection of utility 
 * classes based on Java 1.6, focusing (not only) on Java Swing 
 * and the Geotools library.
 * 
 * The SCHMITZM project is hosted at:
 * http://wald.intevation.org/projects/schmitzm/
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 3
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License (license.txt)
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 * or try this link: http://www.gnu.org/licenses/lgpl.html
 * 
 * Contributors:
 *     Martin O. J. Schmitz - initial API and implementation
 *     Stefan A. Krüger - additional utility classes
 ******************************************************************************/
package schmitzm.swing.tree;

/**
 * Diese Klasse stellt einen Knoten dar, der kein Objekt beinhaltet
 * (sondern nur eine Beschriftung). Er kann deshalb auch nicht
 * editiert werden.
 */
public class EmptyNode extends EditableNode {
  private String desc = "";

  /**
   * Erzeugt einen neuen leeren Knoten.
   */
  public EmptyNode() {
    this("<empty>");
  }

  /**
   * Erzeugt einen neuen leeren Knoten.
   * @param desc Beschreibung fuer den Knoten
   */
  public EmptyNode(String desc) {
    super(false);
    this.desc = desc;
  }

  /**
   * Liefert die Beschreibung des Knotens
   * (anstelle von <code>getUserObject().toString()</code>).
   */
  public String toString() {
    return desc;
  }

  /**
   * Macht nichts, da der Knoten nicht editierbar ist!
   * Ueberschreibt (sicherheitshalber) die Methode der Oberklasse.
   */
  public void setUserObject(Object object) {
  }
}
