/*******************************************************************************
 * Copyright (c) 2009 Martin O. J. Schmitz.
 * 
 * This file is part of the SCHMITZM library - a collection of utility 
 * classes based on Java 1.6, focusing (not only) on Java Swing 
 * and the Geotools library.
 * 
 * The SCHMITZM project is hosted at:
 * http://wald.intevation.org/projects/schmitzm/
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 3
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License (license.txt)
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 * or try this link: http://www.gnu.org/licenses/lgpl.html
 * 
 * Contributors:
 *     Martin O. J. Schmitz - initial API and implementation
 *     Stefan A. Krüger - additional utility classes
 ******************************************************************************/

package skrueger.geotools;

/**
 * Some utility method for {@link Copyable}.
 * @author <a href="mailto:martin.schmitz@koeln.de">Martin Schmitz</a>
 */
public class CopyableUtil {
  
  /**
   * Copies an {@link Copyable} to another. If possible no new destination
   * instance is created, so the "original" destination object is
   * also returned.<br>
   * If {@code source} is {@code null}, the {@code dest} object
   * is irrelevant and {@code null} is returned. If {@code dest} is NULL
   * and {@code source} in not NULL, a new {@code source.copy()} is
   * returned. 
   * @param source the source object (can be {@code null})
   * @param dest   the object, the source values are copied to (can be {@code null})
   */
  public static <T extends Copyable<T>> T copyOrCreate(T source, T dest) {
    // If both objects are not NULL, the source Copyable can be applied
    // to destination Copyable
    if ( source != null && dest != null )
      source.copyTo( dest );
    // Otherwise: If source Copyable is not NULL, but destination a new
    //            destination object is created from source and returned
    else if ( source != null && dest == null )
      dest = source.copy();
    // Otherwise: source Copyable is NULL, so destination must also
    //            be NULL
    else 
      dest = null;
    
    return dest;
  }
}
