/*******************************************************************************
 * Copyright (c) 2009 Martin O. J. Schmitz.
 * 
 * This file is part of the SCHMITZM library - a collection of utility 
 * classes based on Java 1.6, focusing (not only) on Java Swing 
 * and the Geotools library.
 * 
 * The SCHMITZM project is hosted at:
 * http://wald.intevation.org/projects/schmitzm/
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 3
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License (license.txt)
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 * or try this link: http://www.gnu.org/licenses/lgpl.html
 * 
 * Contributors:
 *     Martin O. J. Schmitz - initial API and implementation
 *     Stefan A. Krüger - additional utility classes
 ******************************************************************************/
/** 
 Copyright 2008 Stefan Alfons Krüger and parts from some Geotools code  
 
 atlas-framework - This file is part of the Atlas Framework

 This library is free software; you can redistribute it and/or modify it under the terms of the GNU Lesser General Public License as published by the Free Software Foundation; either version 2.1 of the License, or (at your option) any later version.
 This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more details.
 You should have received a copy of the GNU Lesser General Public License along with this library; if not, write to the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110, USA

 Diese Bibliothek ist freie Software; Sie dürfen sie unter den Bedingungen der GNU Lesser General Public License, wie von der Free Software Foundation veröffentlicht, weiterverteilen und/oder modifizieren; entweder gemäß Version 2.1 der Lizenz oder (nach Ihrer Option) jeder späteren Version.
 Diese Bibliothek wird in der Hoffnung weiterverbreitet, daß sie nützlich sein wird, jedoch OHNE IRGENDEINE GARANTIE, auch ohne die implizierte Garantie der MARKTREIFE oder der VERWENDBARKEIT FÜR EINEN BESTIMMTEN ZWECK. Mehr Details finden Sie in der GNU Lesser General Public License.
 Sie sollten eine Kopie der GNU Lesser General Public License zusammen mit dieser Bibliothek erhalten haben; falls nicht, schreiben Sie an die Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110, USA.
 **/
package skrueger.geotools;

import java.awt.Color;
import java.awt.Dimension;
import java.awt.Graphics2D;
import java.awt.RenderingHints;
import java.awt.image.BufferedImage;

import javax.swing.tree.DefaultTreeCellRenderer;

import org.apache.log4j.Logger;
import org.geotools.factory.GeoTools;
import org.geotools.factory.Hints;
import org.geotools.feature.IllegalAttributeException;
import org.geotools.geometry.jts.LiteShape2;
import org.geotools.renderer.lite.StyledShapePainter;
import org.geotools.renderer.style.SLDStyleFactory;
import org.geotools.renderer.style.Style2D;
import org.geotools.styling.LineSymbolizer;
import org.geotools.styling.PointSymbolizer;
import org.geotools.styling.PolygonSymbolizer;
import org.geotools.styling.RasterSymbolizer;
import org.geotools.styling.Rule;
import org.geotools.styling.Style;
import org.geotools.styling.Symbolizer;
import org.geotools.styling.TextSymbolizer;
import org.geotools.util.NumberRange;
import org.opengis.feature.simple.SimpleFeature;
import org.opengis.feature.simple.SimpleFeatureType;
import org.opengis.feature.type.AttributeDescriptor;

import schmitzm.geotools.feature.FeatureUtil;

import com.vividsolutions.jts.geom.Coordinate;
import com.vividsolutions.jts.geom.GeometryFactory;
import com.vividsolutions.jts.geom.LineString;
import com.vividsolutions.jts.geom.LinearRing;
import com.vividsolutions.jts.geom.Polygon;

/**
 * Based on geoserver!
 * <hr>
 * <b>Changes by <a href="mailto:Martin.Schmitz@koeln.de">Martin Schmitz</a></b>
 * <br>
 * <ul>
 * <li>07.02.2008:<br>
 * Determining the default values of a {@link SimpleFeatureType} by
 * {@link FeatureUtil#getDefaultAttributeValues(SimpleFeatureType)} instead of using
 * {@link AttributeDescriptor#createDefaultValue()} directly, because the latter
 * returns {@code null} even though the attribut is not nillable.</li>
 * </ul>
 * 
 * @author Stefan Alfons Krüger
 */
public class LegendIconFeatureRenderer extends DefaultTreeCellRenderer {
//	private static final Dimension SIZE = new Dimension(30,20);

	Logger LOGGER = Logger.getLogger(LegendIconFeatureRenderer.class);

	/**
	 * This is a static class
	 */
	private LegendIconFeatureRenderer() {
	}

	final static LegendIconFeatureRenderer instance = new LegendIconFeatureRenderer();

	public static LegendIconFeatureRenderer getInstance() {
		// In GT 2.4.5 it we have to create a new one all the time!
		
		// TODO TEST, whether we still need to recreate the renderer here....
		// TODO TEST, whether we still need to recreate the renderer here....
		// TODO TEST, whether we still need to recreate the renderer here....
		// TODO TEST, whether we still need to recreate the renderer here....
		// TODO TEST, whether we still need to recreate the renderer here....
		// TODO TEST, whether we still need to recreate the renderer here....
		// TODO TEST, whether we still need to recreate the renderer here....
		// TODO TEST, whether we still need to recreate the renderer here....
		return new LegendIconFeatureRenderer();
//		 return instance;
	}

	/**
	 * used to create sample point shapes with LiteShape (not lines nor
	 * polygons)
	 */
	private static final GeometryFactory geomFac = FeatureUtil.GEOMETRY_FACTORY;

	/** padding percentage factor at both sides of the legend. */
	private static final float hpaddingFactor = 0.11f; // was 0.15

	/** top & bottom padding percentage factor for the legend */
	private static final float vpaddingFactor = 0.08f; // was 0.15

	/**
	 * Just a holder to avoid creating many polygon shapes from inside
	 * <code>getSampleShape()</code>
	 */
	private LiteShape2 sampleRect;

	/**
	 * Just a holder to avoid creating many line shapes from inside
	 * <code>getSampleShape()</code>
	 */
	private LiteShape2 sampleLine;

	/**
	 * Just a holder to avoid creating many point shapes from inside
	 * <code>getSampleShape()</code>
	 */
	private LiteShape2 samplePoint;

	private Hints hints;

	/**
	 * Returns a <code>java.awt.Shape</code> appropiate to render a legend
	 * graphic given the symbolizer type and the legend dimensions.
	 * 
	 * @param symbolizer
	 *            the Symbolizer for whose type a sample shape will be created
	 * @param legendWidth
	 *            the requested width, in output units, of the legend graphic
	 * @param legendHeight
	 *            the requested height, in output units, of the legend graphic
	 * 
	 * @return an appropiate Line2D, Rectangle2D or LiteShape(Point) for the
	 *         symbolizer, wether it is a LineSymbolizer, a PolygonSymbolizer,
	 *         or a Point ot Text Symbolizer
	 * 
	 * @throws IllegalArgumentException
	 *             if an unknown symbolizer impl was passed in.
	 */
	private LiteShape2 getSampleShape(Symbolizer symbolizer, int legendWidth,
			int legendHeight) {
		LiteShape2 sampleShape;
		final float hpad = (legendWidth * hpaddingFactor);
		final float vpad = (legendHeight * vpaddingFactor);

		if (symbolizer instanceof LineSymbolizer) {
			if (this.sampleLine == null) {
				Coordinate[] coords = {
						new Coordinate(hpad, legendHeight - vpad),
						new Coordinate(legendWidth - hpad, vpad) };
				LineString geom = geomFac.createLineString(coords);

				try {
					this.sampleLine = new LiteShape2(geom, null, null, false);
				} catch (Exception e) {
					this.sampleLine = null;
				}
			}

			sampleShape = this.sampleLine;
		} else if ((symbolizer instanceof PolygonSymbolizer)
				|| (symbolizer instanceof RasterSymbolizer)) {
			if (this.sampleRect == null) {
				final float w = legendWidth - (2 * hpad);
				final float h = legendHeight - (2 * vpad);

				Coordinate[] coords = { new Coordinate(hpad, vpad),
						new Coordinate(hpad, vpad + h),
						new Coordinate(hpad + w, vpad + h),
						new Coordinate(hpad + w, vpad),
						new Coordinate(hpad, vpad) };
				LinearRing shell = geomFac.createLinearRing(coords);
				Polygon geom = geomFac.createPolygon(shell, null);

				try {
					this.sampleRect = new LiteShape2(geom, null, null, false);
				} catch (Exception e) {
					this.sampleRect = null;
				}
			}

			sampleShape = this.sampleRect;
		} else if (symbolizer instanceof PointSymbolizer
				|| symbolizer instanceof TextSymbolizer) {
			if (this.samplePoint == null) {
				Coordinate coord = new Coordinate(legendWidth / 2,
						legendHeight / 2);

				try {
					this.samplePoint = new LiteShape2(geomFac
							.createPoint(coord), null, null, false);
				} catch (Exception e) {
					this.samplePoint = null;
				}
			}

			sampleShape = this.samplePoint;
		} else {
			throw new IllegalArgumentException("Unknown symbolizer: "
					+ symbolizer);
		}
		return sampleShape;
	}
	
	/**
	 * Creates a little BufferedImage that presents the Style/Symbols used by
	 * the {@link MapLegend} to show a legend for the {@link SimpleFeatureType}
	 * 
	 * @param rule
	 *            {@link Rule} that provides the text and the style to present
	 * @param featureType
	 *            Schema that describes the kind of the sample {@link SimpleFeature}
	 *            that will be rendered with the {@link Style}
	 * @param bg
	 *            Background {@link Color} or <code>null</code>
	 * 
	 * @throws IllegalAttributeException
	 */
	public BufferedImage createImageForRule(Rule rule, SimpleFeatureType featureType,
			Dimension size, Color bg) {

		Symbolizer[] symbolizers = rule.getSymbolizers();

		BufferedImage buffImage = new BufferedImage(size.width, size.height,
				BufferedImage.TYPE_INT_ARGB);
		Graphics2D graphics = buffImage.createGraphics();

		if (bg != null) {
			// ****************************************************************************
			// The following lines define the backgroup color for the rendered
			// images
			// ****************************************************************************
			graphics.setBackground(bg);
			graphics.setColor(bg);
			graphics.fillRect(0, 0, size.width, size.height);
		}

		// Enable anti-aliasing for the legend symbols
		graphics.setRenderingHints(getHints());

		// TODO scaleDenominator = 100000000000000000000000000000d; Was ist das
		// fuer ein Quatsch?
		final NumberRange<Integer> scaleRange = NumberRange.create(Integer.MAX_VALUE,Integer.MAX_VALUE);

		try {

			for (int sIdx = 0; sIdx < symbolizers.length; sIdx++) {
				Symbolizer symbolizer = symbolizers[sIdx];

				if (symbolizer instanceof TextSymbolizer) {
					LOGGER
							.warn("createImageForRule for a TextSymbolizer. Sure we want that?");
					continue;
				}

				// if (symbolizer instanceof RasterSymbolizer) {
				// log.warn("createImageForRule method can't be used for
				// RasterSymbolizers..");
				// }
				// else
				final SimpleFeature sampleFeature = FeatureUtil.createSampleFeature(featureType);

				// The SLDStyleFactory has to be recreated, as it seams to cache
				// some stuff.
				SLDStyleFactory sldStyleFactory = new SLDStyleFactory();
				Style2D style2d = sldStyleFactory.createStyle(sampleFeature,
						symbolizer, scaleRange);

				LiteShape2 shape = getSampleShape(symbolizer, size.width,
						size.height);

				if (style2d != null) {
					new StyledShapePainter(null).paint(graphics, shape,
							style2d, Integer.MAX_VALUE );
				}
			}
		} catch (Exception e) {
			LOGGER
					.error(
							"Error during createImageForRule, returning empty Image",
							e);
		}
		return buffImage;
	}

	/**
	 * Define Java2D and other Hints
	 * 
	 * @param hints
	 * @author <a href="mailto:skpublic@wikisquare.de">Stefan Alfons
	 *         Kr&uuml;ger</a>
	 */
	public void setHints(Hints hints) {
		getHints().add(hints);
	}

	private Hints getHints() {
		if (hints == null) {
			hints = GeoTools.getDefaultHints();
			hints.put(RenderingHints.KEY_ANTIALIASING,
					RenderingHints.VALUE_ANTIALIAS_ON);
			hints.put(RenderingHints.KEY_TEXT_ANTIALIASING,
					RenderingHints.VALUE_TEXT_ANTIALIAS_GASP);
			hints.put(RenderingHints.KEY_ALPHA_INTERPOLATION,
					RenderingHints.VALUE_ALPHA_INTERPOLATION_QUALITY);
			hints.put(RenderingHints.KEY_RENDERING,
					RenderingHints.VALUE_RENDER_QUALITY);
			hints.put(RenderingHints.KEY_COLOR_RENDERING,
					RenderingHints.VALUE_COLOR_RENDER_QUALITY);
		}
		return hints;
	}

	/**
	 * Creates a little BufferedImage that presents the Style/Symbols used by
	 * the {@link MapLegend} to show a legend for the {@link SimpleFeatureType}
	 * 
	 * @param rule
	 *            {@link Rule} that provides the text and the style to present
	 * @param featureType
	 *            Schema that describes the kind of the sample {@link SimpleFeature}
	 *            that will be rendered with the {@link Style}
	 * 
	 * @throws IllegalAttributeException
	 */
	public BufferedImage createImageForRule(final Rule rule,
			final SimpleFeatureType featureType, final Dimension size) {
		return createImageForRule(rule, featureType, size, null);
	}

}
