/*******************************************************************************
 * Copyright (c) 2009 Martin O. J. Schmitz.
 * 
 * This file is part of the SCHMITZM library - a collection of utility 
 * classes based on Java 1.6, focusing (not only) on Java Swing 
 * and the Geotools library.
 * 
 * The SCHMITZM project is hosted at:
 * http://wald.intevation.org/projects/schmitzm/
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 3
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License (license.txt)
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 * or try this link: http://www.gnu.org/licenses/lgpl.html
 * 
 * Contributors:
 *     Martin O. J. Schmitz - initial API and implementation
 *     Stefan A. Krüger - additional utility classes
 ******************************************************************************/
package skrueger.geotools;

import java.awt.BorderLayout;
import java.awt.Component;

import javax.swing.BorderFactory;
import javax.swing.JComponent;
import javax.swing.JPanel;
import javax.swing.JSplitPane;

import net.miginfocom.swing.MigLayout;

import org.apache.log4j.Logger;

import schmitzm.geotools.gui.GeoMapPane;
import schmitzm.geotools.gui.MapContextControlPane;
import schmitzm.geotools.gui.MapPaneStatusBar;
import schmitzm.geotools.gui.SelectableXMapPane;
import schmitzm.geotools.styling.ColorMapManager;

/**
 * Achtung! Dieser code ist verwuestet TODO DOKU und initialize schöner machen.
 * SK
 */
public class MapView extends JPanel {
	private static final Logger LOGGER = Logger.getLogger(MapView.class);

	private final JSplitPane splitPane = new JSplitPane(
			JSplitPane.HORIZONTAL_SPLIT);

	protected MapPaneStatusBar statusBar = null;

	/**
	 * Komponente, in der die Karten, der Massstab und das Koordinaten-Raster
	 * dargestellt werden.
	 */

	protected final GeoMapPane geoMapPane = new GeoMapPane();

	private MapPaneToolBar jToolBar;

	/**
	 * Creates a new {@link MapView}. A {@link MapView} is a combination of a
	 * {@link GeoMapPane}, a {@link MapContextManagerInterface} on the left, and
	 * some buttons floating over the {@link SelectableXMapPane}
	 */
	public MapView(Component parentGui, MapPaneToolBar toolBar) {
		super(new BorderLayout());
		// Call initialize() by yourself afterwards.
		// Needed because variables for the overwritten methods
		// are not yet set.
		jToolBar = toolBar;
	}

	/**
	 * Creates a new {@link MapView}. A {@link MapView} is a combination of a
	 * {@link GeoMapPane}, a {@link MapContextManagerInterface} on the left, and
	 * some buttons floating over the {@link SelectableXMapPane}
	 */
	public MapView(Component parentGui) {
		this(parentGui, null);
	}

	/**
	 * This routine creates the main components of the GUI: The left Side and
	 * the map on the right side.<br/>
	 * Calls #getSidePanel() which can be overwritten (call super!).<br/>
	 * 
	 * This method initialized the variables {@link #statusBar} and
	 * {@link #splitPane}
	 * 
	 * @see #adjustSizeOfGeoMapPane()
	 */
	public void initialize() {
		// horizontales SplitPane initialisieren

		// Status-Line to show Coordinates and Rastervalues.
		statusBar = new MapPaneStatusBar(getGeoMapPane().getMapPane());
		statusBar.setBorder(BorderFactory.createCompoundBorder(BorderFactory
				.createLoweredBevelBorder(), BorderFactory.createEmptyBorder(2,
				5, 2, 5)));
		this.add(statusBar, BorderLayout.SOUTH);

		/**
		 * The layout of the split pane can be configured in the atlas.
		 * setDividerLocation(-1); has no effect here because the component is
		 * not visible yet.
		 */
		getSplitPane().setDividerSize(5);

		getSplitPane().setResizeWeight(0.0);
		getSplitPane().add(getSidePane());

		/***********************************************************************
		 * To the right side we now add a JPanel that consists of a toolbar and
		 * a gmp
		 */
		JPanel newRight = new JPanel(new MigLayout("center, wrap 1","[grow]","[][grow]"));
		newRight.add(getToolBar());
		newRight.add(getGeoMapPane(),"growx, growy");
		getSplitPane().add(newRight);

		this.add(getSplitPane(), BorderLayout.CENTER);
		
	}

	/**
	 * Returns the tool bar which controls the active mouse actions on the map.
	 * 
	 * @return never <code>null</code>, will rather create a default
	 */
	public MapPaneToolBar getToolBar() {
		if (jToolBar == null) {
			jToolBar = new MapPaneToolBar(getMapPane());
		}
		return jToolBar;
	}

	/**
	 * Returns the split pane which divides the layer list from the map panel.
	 */
	public JSplitPane getSplitPane() {
		return splitPane;
	}

	/**
	 * Sets the active tool. Simply calls
	 * {@link MapPaneToolBar#setSelectedTool(Integer)}.
	 * 
	 * @param tool
	 *            One of {@link #TOOL_INFO}, {@link #TOOL_PAN} .. constants
	 */
	public void setSelectedTool(Integer tool) {
		jToolBar.setSelectedTool(tool);
	}

	/**
	 * Sets whether a tool is activated or not. Simply calls
	 * {@link MapPaneToolBar#setButtonEnabled(int, boolean, boolean)}.
	 * 
	 * @param tool
	 *            tool ID
	 * @param enabled
	 *            if {@code true} the tool becomes available
	 * @param hideOnDisable
	 *            if {@code true} the button is also hidden if {@code enabled}
	 *            is {@code false}
	 */
	public void setToolEnabled(Integer tool, boolean enabled,
			boolean hideOnDisable) {
		jToolBar.setButtonEnabled(tool, enabled, hideOnDisable);
	}

	/**
	 * Sets the activation for all tools. Simply calls
	 * {@link MapPaneToolBar#setAllToolsEnabled(boolean, boolean)}.
	 * 
	 * @param enabled
	 *            if {@code true} all tool becomes available
	 * @param hideOnDisable
	 *            if {@code true} the buttons are also hidden if {@code enabled}
	 *            is {@code false}
	 */
	public void setAllToolsEnabled(boolean enabled, boolean hideOnDisable) {
		jToolBar.setAllToolsEnabled(enabled, hideOnDisable);
	}

	/**
	 * Checks whether a tool is activated. Simply calls
	 * {@link MapPaneToolBar#isButtonEnabled(Integer)}.
	 * 
	 * @param tool
	 *            tool ID
	 * @return {@code false} if an unknown ID is specified
	 */
	public boolean isToolEnabled(Integer tool) {
		return jToolBar.isButtonEnabled(tool);
	}

	/**
	 * called by initialize() to fill the left of the XULUMapView Supposed to be
	 * overwritten by AtlasMapView or DesignMapView
	 */
	public JComponent getSidePane() {
		return new MapContextControlPane(getGeoMapPane().getMapPane(),
				new ColorMapManager());
	}

	/**
	 * Liefert die Status-Zeile, in der die Koordinaten und Raster-Werte
	 * angezeigt werden.
	 */
	public MapPaneStatusBar getStatusBar() {
		return this.statusBar;
	}

	/**
	 * Liefert den Karten-Bereich der Komponente.
	 */
	public final SelectableXMapPane getMapPane() {
		return getGeoMapPane().getMapPane();
	}

	public GeoMapPane getGeoMapPane() {
		return geoMapPane;
	}

	public int getSelectedTool() {
		return jToolBar.getSelectedTool();
	}

	/**
	 * Help the garbage collection
	 */
	public void dispose() {
		if (geoMapPane != null)
			geoMapPane.dispose();
	}

}
