/*******************************************************************************
 * Copyright (c) 2009 Martin O. J. Schmitz.
 * 
 * This file is part of the SCHMITZM library - a collection of utility 
 * classes based on Java 1.6, focusing (not only) on Java Swing 
 * and the Geotools library.
 * 
 * The SCHMITZM project is hosted at:
 * http://wald.intevation.org/projects/schmitzm/
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 3
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License (license.txt)
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 * or try this link: http://www.gnu.org/licenses/lgpl.html
 * 
 * Contributors:
 *     Martin O. J. Schmitz - initial API and implementation
 *     Stefan A. Krüger - additional utility classes
 ******************************************************************************/
package skrueger.geotools;

import org.geotools.data.FeatureSource;
import org.geotools.feature.FeatureCollection;
import org.opengis.feature.simple.SimpleFeature;
import org.opengis.feature.simple.SimpleFeatureType;
import org.opengis.filter.Filter;

/**
 * This Interface combines all styled layers that are running on
 * {@link FeatureCollection} or {@link FeatureSource}
 * 
 * @author Stefan A. Krüger
 * 
 * @param <T>
 *            The base Type returned in the getObject() method.
 */
public interface StyledFeaturesInterface<T> extends StyledLayerInterface<T> {

	public abstract AttributeMetadataMap getAttributeMetaDataMap();

	/**
	 * @return The features of this layer as a {@link FeatureSource}. The filter
	 *         is NOT automatically applied.
	 */
	public FeatureSource<SimpleFeatureType, SimpleFeature> getFeatureSource();

	/**
	 * @return The features of this layer as a {@link FeatureCollection}. The
	 *         filter is NOT automatically applied.
	 */
	public abstract FeatureCollection<SimpleFeatureType, SimpleFeature> getFeatureCollection();

	/**
	 * @return The features of this layer as a {@link FeatureCollection}. The
	 *         associated Filter is automatically applied.
	 */
	public abstract FeatureCollection<SimpleFeatureType, SimpleFeature> getFeatureCollectionFiltered();

	/**
	 * Stores Filter that is NOT automatically applied. <code>null</code> is not
	 * allowed, use Filter.INCLUDE.
	 */
	public void setFilter(Filter filter);

	/**
	 * Returns the Filter a filter that is associated with this
	 * {@link StyledFeaturesInterface} Never shall return <code>null</code>, but
	 * rather Filter.INCLUDE.
	 */
	public Filter getFilter();

	/**
	 * Returns the underlying GeoTools Object. The filter is NOT applied.
	 * 
	 * @throws RuntimeException
	 * 
	 * @deprected Please use {@link #getFeatureSource()} or
	 *            {@link #getFeatureCollection()} so you save a cast
	 */
	public T getGeoObject();

	/**
	 * @return As the fastest way to get the Schema is depending on the
	 *         underlying geoObject (FeatureSource or FeatureCollection), this
	 *         method shall be implemented in the classes.
	 */
	public abstract SimpleFeatureType getSchema();

}
