/*******************************************************************************
 * Copyright (c) 2009 Martin O. J. Schmitz.
 * 
 * This file is part of the SCHMITZM library - a collection of utility 
 * classes based on Java 1.6, focusing (not only) on Java Swing 
 * and the Geotools library.
 * 
 * The SCHMITZM project is hosted at:
 * http://wald.intevation.org/projects/schmitzm/
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 3
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License (license.txt)
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 * or try this link: http://www.gnu.org/licenses/lgpl.html
 * 
 * Contributors:
 *     Martin O. J. Schmitz - initial API and implementation
 *     Stefan A. Krüger - additional utility classes
 ******************************************************************************/
package skrueger.geotools;

import org.geotools.styling.Style;

/**
 * This class combines a Geotools visualisation {@link Style} with additional
 * meta data needed for visualisation (for example legend data).
 * The class {@code E} defines the type of the meta data.
 * @author <a href="mailto:martin.schmitz@koeln.de">Martin Schmitz</a> (University of Bonn/Germany)
 * @version 1.0
 */
public class StyledLayerStyle<E> {
  /** Holds the Geotools {@link Style} for the geo object visualisation. */
  protected Style geoObjectStyle = null;
  /** Holds the additional meta data for object visualisation (for example
   *  legend information). */
  protected E metaData = null;

  /**
   * Creates a new style for a {@link StyledLayerInterface}.
   * @param style Style
   * @param metaData E
   */
  public StyledLayerStyle(Style style, E metaData) {
    setGeoObjectStyle(style);
    setMetaData(metaData);
  }

  /**
   * Returns the additional meta data needed for object visualisation.
   */
  public E getMetaData() {
    return metaData;
  }

  /**
   * Sets the additional meta data needed for object visualisation.
   * @param metaData the meta data
   */
  public void setMetaData(E metaData) {
    this.metaData = metaData;
  }

  /**
   * Returns the Geotools style for the object visualisation.
   */
  public Style getGeoObjectStyle() {
    return geoObjectStyle;
  }

  /**
   * Sets the Geotools style for the object visualisation.
   * @param style a Geotools visualisation style
   */
  public void setGeoObjectStyle(Style style) {
    this.geoObjectStyle = style;
  }
}
