/*******************************************************************************
 * Copyright (c) 2009 Martin O. J. Schmitz.
 * 
 * This file is part of the SCHMITZM library - a collection of utility 
 * classes based on Java 1.6, focusing (not only) on Java Swing 
 * and the Geotools library.
 * 
 * The SCHMITZM project is hosted at:
 * http://wald.intevation.org/projects/schmitzm/
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 3
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License (license.txt)
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 * or try this link: http://www.gnu.org/licenses/lgpl.html
 * 
 * Contributors:
 *     Martin O. J. Schmitz - initial API and implementation
 *     Stefan A. Krüger - additional utility classes
 ******************************************************************************/

package skrueger.geotools;

import java.awt.Point;
import java.awt.event.MouseEvent;
import java.awt.event.MouseWheelEvent;

import org.opengis.geometry.DirectPosition;

/**
 * Empty implementation of {@link XMapPaneAction}. No method of this class
 * does anything.
 * @author <a href="mailto:martin.schmitz@koeln.de">Martin Schmitz</a> (University of Bonn/Germany)
 */
public class XMapPaneActionAdapter implements XMapPaneAction {

  /**
   * Implements the action on a mouse click event. Does nothing.
   */
  @Override
  public void performClick(XMapPane mapPane, MouseEvent ev, DirectPosition coord) {
  }

  /**
   * Implements the action AFTER a mouse drag has ended. Does nothing.
   */
  @Override
  public void performDragged(XMapPane mapPane, MouseEvent ev,
      Point dragStartPos, Point dragLastPos, DirectPosition startCoord,
      DirectPosition endCoord) {
  }

  /**
   * Implements the action DURING a mouse drag. Does nothing.
   */
  @Override
  public void performDragging(XMapPane mapPane, MouseEvent ev,
      Point dragStartPos, Point dragLastPos, DirectPosition startCoord,
      DirectPosition endCoord) {
  }

  /**
   * Implements the action on a keyboard stroke. Does nothing.
   */
  @Override
  public void performKeyboard(XMapPane mapPane, Object param) {
  }

  /**
   * Implements the action on mouse wheel event. Does nothing.
   */
  @Override
  public void performWheel(XMapPane mapPane, MouseWheelEvent ev,
      DirectPosition coord) {
  }

}
