package skrueger.geotools;

import java.awt.Color;
import java.awt.Point;
import java.awt.event.MouseEvent;
import java.awt.event.MouseWheelEvent;
import java.awt.geom.Point2D;
import java.util.Enumeration;
import java.util.Hashtable;
import java.util.Iterator;

import org.geotools.data.memory.MemoryFeatureCollection;
import org.geotools.feature.FeatureCollection;
import org.geotools.map.MapLayer;
import org.opengis.feature.simple.SimpleFeature;
import org.opengis.feature.simple.SimpleFeatureType;
import org.opengis.geometry.DirectPosition;

import schmitzm.geotools.gui.SelectableXMapPane;
import schmitzm.geotools.map.event.FeatureSelectedEvent;
import skrueger.geotools.GeomFilterGenerator.PointFilterGenerator;

import com.vividsolutions.jts.geom.Coordinate;
import com.vividsolutions.jts.geom.Envelope;
import com.vividsolutions.jts.geom.Geometry;
import com.vividsolutions.jts.geom.GeometryFactory;

public abstract class XMapPaneAction_Select implements XMapPaneAction {
	//	
	// /**
	// * Flag fuer Modus "SimpleFeature-Auswahl auf allen (sichtbaren) Layern".
	// *
	// * @see #setState(int)
	// * @see #setState(int)
	// */
	// public static enum SelMode {
	// SELECT_ALL
	// }

	public void performClick(XMapPane xMapPane, MouseEvent ev,
			DirectPosition geoCoord) {

		SelectableXMapPane sexMapPane = (SelectableXMapPane) xMapPane;

		// calculate a circle radius around the mouse position
		double radius = DEFAULT_DISTANCE_FRACTION
				* (xMapPane.getMapArea().getWidth() + xMapPane.getMapArea()
						.getHeight()) / 2;

		// Fenster-Koordinate in Geo-Koordinate umwandelt
		Point2D geoPoint = xMapPane.getScreenToWorld().transform(ev.getPoint(),
				null);

		PointFilterGenerator filterGenerator = new PointFilterGenerator(
				geoCoord, radius);
		Hashtable<MapLayer, FeatureCollection<SimpleFeatureType, SimpleFeature>> result = sexMapPane
				.findVisibleFeatures(filterGenerator, getSelectionMode(),
						new Envelope(geoPoint.getX(), geoPoint.getX(), geoPoint
								.getY(), geoPoint.getY()));

		// Ein Event auslösen für das jeweils nächste Feature pro Layer
		for (Enumeration<MapLayer> element = result.keys(); element
				.hasMoreElements();) {

			MapLayer layer = element.nextElement();
			FeatureCollection<SimpleFeatureType, SimpleFeature> fc = result
					.get(layer);
			FeatureCollection<SimpleFeatureType, SimpleFeature> fcOne;

			if (fc != null && !fc.isEmpty()) {

				if (fc.size() > 1) {
					// If the result contains more that one feature, we only
					// return the nearest one.

					SimpleFeature nearestFeature = null;
					Double nearestDist = 0.0;

					Iterator<SimpleFeature> fcIt = fc.iterator();
					try {
						com.vividsolutions.jts.geom.Point mousePoint = new GeometryFactory()
								.createPoint(new Coordinate(geoPoint.getX(),
										geoPoint.getY()));

						while (fcIt.hasNext()) {
							SimpleFeature f = fcIt.next();
							Geometry obj = (Geometry) f
									.getDefaultGeometryProperty().getValue();

							// TODO Hier muss doch irgendwie noch CRS
							// umgewrechnet werden...

							Geometry featureGeometry = (Geometry) obj;

							double distance = featureGeometry
									.distance(mousePoint);

							if ((nearestFeature == null)
									|| (distance < nearestDist)) {
								nearestFeature = f;
								nearestDist = distance;
							}

						}

					} finally {
						fc.close(fcIt);
					}

					fcOne = new MemoryFeatureCollection(fc.getSchema());
					fc.clear();
					fcOne.add(nearestFeature);
				} else {
					fcOne = fc;
				}

				// Fire the event with the one selected feature
				sexMapPane.fireMapPaneEvent(new FeatureSelectedEvent(
						sexMapPane, layer, fcOne.getBounds(), fcOne));
			}
		}

		// If no vector features were found, or we are in SELECT_ALL mode, we
		// check the raster layers now
		if (getSelectionMode() == SelectableXMapPane.SELECT_ALL || result.isEmpty()) {
			sexMapPane.findGridCoverageValuesAndFireEvents(geoPoint,
					getSelectionMode());
		}
	}

	/**
	 * Does nothing if initiated by keyboard.
	 * 
	 * TODO select all features should be assignable to Strg-A
	 */
	@Override
	public void performKeyboard(XMapPane mapPane, Object param) {
	}

	/**
	 * Default distance fraction used with line and point features. When the
	 * user clicks on the map, this tool searches for features within a
	 * rectangle of width w centered on the mouse location, where w is the
	 * average map side length multiplied by the value of this constant.
	 */
	public static final double DEFAULT_DISTANCE_FRACTION = 0.01d;

	// @Override
	// public void performClick(XMapPane xMapPane, MouseEvent ev,
	// DirectPosition geoCoord) {
	//			
	// performSelectionClick(xMapPane, ev, geoCoord, XMapPane.SELECT_ALL);
	// }

	@Override
	public void performDragged(XMapPane mapPane, MouseEvent ev,
			Point dragStartPos, Point dragLastPos, DirectPosition startCoord,
			DirectPosition endCoord) {

		SelectableXMapPane sexMapPane = (SelectableXMapPane) mapPane;

		Point mp = ev.getPoint();

		// Ist es eine wirkliche Selektion, oder etwas nur ein Klick?
		if (dragStartPos.x != mp.x && dragStartPos.y != mp.y) {
			sexMapPane.drawRectangle(sexMapPane.getGraphics(), dragStartPos, ev
					.getPoint(), Color.BLUE.brighter(), true);
		}

		// SELECTION!
		sexMapPane.performSelectionEvent(dragStartPos.x, dragStartPos.y, mp.x,
				mp.y, getSelectionMode());
	}

	abstract int getSelectionMode();

	@Override
	public void performDragging(XMapPane mapPane, MouseEvent ev,
			Point dragStartPos, Point dragLastPos, DirectPosition startCoord,
			DirectPosition endCoord) {
		if (dragLastPos != null)
			mapPane.drawRectangle(mapPane.getGraphics(), dragStartPos,
					dragLastPos, Color.BLUE.brighter(), true);

		mapPane.drawRectangle(mapPane.getGraphics(), dragStartPos, ev
				.getPoint(), Color.BLUE.brighter(), true);
	}

	@Override
	public void performWheel(XMapPane mapPane, MouseWheelEvent ev,
			DirectPosition coord) {
	}

	public static class All extends XMapPaneAction_Select {

		int getSelectionMode() {
			return SelectableXMapPane.SELECT_ALL;
		}
	}

	public static class OneFromTop extends XMapPaneAction_Select {

		int getSelectionMode() {
			return SelectableXMapPane.SELECT_ONE_FROM_TOP;
		}
	}

	public static class Top extends XMapPaneAction_Select {

		int getSelectionMode() {
			return SelectableXMapPane.SELECT_TOP;
		}
	}

}
