package skrueger.geotools;

import java.awt.Point;
import java.awt.Rectangle;
import java.awt.event.MouseEvent;
import java.awt.event.MouseWheelEvent;
import java.awt.geom.Point2D;

import org.opengis.geometry.DirectPosition;

import schmitzm.geotools.JTSUtil;

import com.vividsolutions.jts.geom.Coordinate;
import com.vividsolutions.jts.geom.Envelope;

public abstract class XMapPaneAction_Zoom implements XMapPaneAction {

	@Override
	public void performDragging(XMapPane mapPane, MouseEvent ev,
			Point dragStartPos, Point dragLastPos,
			DirectPosition startCoord, DirectPosition endCoord) {

		if (dragLastPos != null)
			mapPane.drawRectangle(mapPane.getGraphics(), dragStartPos,
					dragLastPos);

		mapPane.drawRectangle(mapPane.getGraphics(), dragStartPos, ev
				.getPoint());
	}

	public static class In extends XMapPaneAction_Zoom {

		@Override
		public void performClick(XMapPane mapPane, MouseEvent ev,
				DirectPosition coord) {

			mapPane.zoomTo(ev.getPoint(), 1 / 2.);
		}

		@Override
		public void performWheel(XMapPane mapPane, MouseWheelEvent wheelEvt,
				DirectPosition coord) {

	        int units = wheelEvt.getUnitsToScroll();
	        // Positiver Wert --> Zoom in --> Faktor < 1
	        // Negativer Wert --> Zoom out --> Faktir > 1

	        // SK: 9.9.2007 zoom jetzt wie bei GoogleEarth
	        double zFactor = units > 0 ? 1.3 : 1 / 1.3;
	        // vorher double zFactor = units > 0 ? 1/1.2 : 1.2;

	        // Fenster-Koordinaten zu Karten-Koordinaten transformieren
	        Point2D mapCoord = XMapPane.getMapCoordinatesFromEvent(wheelEvt);
	        // Relative Position des Mauszeigers zum Kartenausschnitt
	        // -> Nach Zoom soll dieselbe Kartenposition unterhalb des Mauszeigers
	        // erscheinen, wie vor dem Zoom
	        double relX = (mapCoord.getX() - mapPane.getMapArea().getMinX())
	                / mapPane.getMapArea().getWidth();
	        double relY = (mapCoord.getY() - mapPane.getMapArea().getMinY())
	                / mapPane.getMapArea().getHeight();

	        // Neuen Karten-Ausschnitt berechnen
	        Coordinate ll = new Coordinate(mapCoord.getX()
	                - mapPane.getMapArea().getWidth() * relX * zFactor, mapCoord.getY()
	                - mapPane.getMapArea().getHeight() * relY * zFactor);
	        Coordinate ur = new Coordinate(mapCoord.getX()
	                + mapPane.getMapArea().getWidth() * (1 - relX) * zFactor, mapCoord
	                .getY()
	                + mapPane.getMapArea().getHeight() * (1 - relY) * zFactor);
	        mapPane.setMapArea(new Envelope(ll, ur));
		}

		@Override
		public void performDragged(XMapPane mapPane, MouseEvent ev,
				Point dragStartPos, Point dragLastPos,
				DirectPosition startCoord, DirectPosition endCoord) {

			if (dragLastPos != null)
				mapPane.drawRectangle(mapPane.getGraphics(), dragStartPos,
						dragLastPos);

			// If this is similar to a click, let mouseClicked handle it!
			if ((Math.abs(dragStartPos.x - ev.getPoint().x) * Math.abs(ev
					.getPoint().y
					- dragStartPos.y)) < 160) {
				// performClick(mapPane, ev, coord)
				return;
			}

			final Rectangle bounds = mapPane.getBounds();

			Envelope mapArea = mapPane.getMapArea();

			// Replace with transform and translate
			final double mapWidth = mapArea.getWidth();
			final double mapHeight = mapArea.getHeight();

			final double startX = ((dragStartPos.x * mapWidth) / (double) bounds.width)
					+ mapArea.getMinX();
			final double startY = (((bounds.getHeight() - dragStartPos.y) * mapHeight) / (double) bounds.height)
					+ mapArea.getMinY();
			final double endX = ((ev.getPoint().x * mapWidth) / (double) bounds.width)
					+ mapArea.getMinX();
			final double endY = (((bounds.getHeight() - ev.getPoint().y) * mapHeight) / (double) bounds.height)
					+ mapArea.getMinY();

			final double left = Math.min(startX, endX);
			final double right = Math.max(startX, endX);
			final double bottom = Math.min(startY, endY);
			final double top = Math.max(startY, endY);
			final Coordinate ll = new Coordinate(left, bottom);
			final Coordinate ur = new Coordinate(right, top);

			mapPane.setMapArea(new Envelope(ll, ur));

		}
		
		/**
		 * @param param is ignored
		 */
		@Override
		public void performKeyboard(XMapPane mapPane, Object param) {
			mapPane.setMapArea( JTSUtil.expandEnvelope(mapPane.getMapArea(), -.10) );
		}

	}

	public static class Out extends XMapPaneAction_Zoom {
		
		/**
		 * @param param is ignored
		 */
		@Override
		public void performKeyboard(XMapPane mapPane, Object param) {
			mapPane.setMapArea( JTSUtil.expandEnvelope(mapPane.getMapArea(), .10) );
			}

		@Override
		public void performClick(XMapPane mapPane, MouseEvent ev,
				DirectPosition coord) {

			mapPane.zoomTo(ev.getPoint(), 2.);
		}

		@Override
		public void performWheel(XMapPane mapPane, MouseWheelEvent wheelEvt,
				DirectPosition coord) {
          int units = wheelEvt.getUnitsToScroll();
          // Positiver Wert --> Zoom in --> Faktor < 1
          // Negativer Wert --> Zoom out --> Faktir > 1

          // SK: 9.9.2007 zoom jetzt wie bei GoogleEarth
          double zFactor = units > 0 ? 1.3 : 1 / 1.3;
          // vorher double zFactor = units > 0 ? 1/1.2 : 1.2;

          // Fenster-Koordinaten zu Karten-Koordinaten transformieren
          Point2D mapCoord = XMapPane.getMapCoordinatesFromEvent(wheelEvt);
          // Relative Position des Mauszeigers zum Kartenausschnitt
          // -> Nach Zoom soll dieselbe Kartenposition unterhalb des Mauszeigers
          // erscheinen, wie vor dem Zoom
          double relX = (mapCoord.getX() - mapPane.getMapArea().getMinX())
                  / mapPane.getMapArea().getWidth();
          double relY = (mapCoord.getY() - mapPane.getMapArea().getMinY())
                  / mapPane.getMapArea().getHeight();

          // Neuen Karten-Ausschnitt berechnen
          Coordinate ll = new Coordinate(mapCoord.getX()
                  - mapPane.getMapArea().getWidth() * relX * zFactor, mapCoord.getY()
                  - mapPane.getMapArea().getHeight() * relY * zFactor);
          Coordinate ur = new Coordinate(mapCoord.getX()
                  + mapPane.getMapArea().getWidth() * (1 - relX) * zFactor, mapCoord
                  .getY()
                  + mapPane.getMapArea().getHeight() * (1 - relY) * zFactor);
          mapPane.setMapArea(new Envelope(ll, ur));
		}


		@Override
		public void performDragged(XMapPane mapPane, MouseEvent ev,
				Point dragStartPos, Point dragLastPos,
				DirectPosition startCoord, DirectPosition endCoord) {

			if (dragLastPos != null)
				mapPane.drawRectangle(mapPane.getGraphics(), dragStartPos,
						dragLastPos);

			// If this is similar to a click, let mouseClicked handle it!
			if ((Math.abs(dragStartPos.x - ev.getPoint().x) * Math.abs(ev
					.getPoint().y
					- dragStartPos.y)) < 160) {
				// performClick(mapPane, ev, coord)
				return;
			}

			final Rectangle bounds = mapPane.getBounds();

			Envelope mapArea = mapPane.getMapArea();

			// Replace with transform and translate
			final double mapWidth = mapArea.getWidth();
			final double mapHeight = mapArea.getHeight();

			final double startX = ((dragStartPos.x * mapWidth) / (double) bounds.width)
					+ mapArea.getMinX();
			final double startY = (((bounds.getHeight() - dragStartPos.y) * mapHeight) / (double) bounds.height)
					+ mapArea.getMinY();
			final double endX = ((ev.getPoint().x * mapWidth) / (double) bounds.width)
					+ mapArea.getMinX();
			final double endY = (((bounds.getHeight() - ev.getPoint().y) * mapHeight) / (double) bounds.height)
					+ mapArea.getMinY();

			// make the dragged rectangle in screen coords the new map size?
			final double left = Math.min(startX, endX);
			final double right = Math.max(startX, endX);
			final double bottom = Math.min(startY, endY);
			final double top = Math.max(startY, endY);
			final double nWidth = (mapWidth * mapWidth) / (right - left);
			final double nHeight = (mapHeight * mapHeight) / (top - bottom);
			final double deltaX1 = left - mapArea.getMinX();
			final double nDeltaX1 = (deltaX1 * nWidth) / mapWidth;
			final double deltaY1 = bottom - mapArea.getMinY();
			final double nDeltaY1 = (deltaY1 * nHeight) / mapHeight;
			final Coordinate ll = new Coordinate(mapArea.getMinX() - nDeltaX1,
					mapArea.getMinY() - nDeltaY1);
			final double deltaX2 = mapArea.getMaxX() - right;
			final double nDeltaX2 = (deltaX2 * nWidth) / mapWidth;
			final double deltaY2 = mapArea.getMaxY() - top;
			final double nDeltaY2 = (deltaY2 * nHeight) / mapHeight;
			final Coordinate ur = new Coordinate(mapArea.getMaxX() + nDeltaX2,
					mapArea.getMaxY() + nDeltaY2);

			mapPane.setMapArea(new Envelope(ll, ur));

		}
	}
}