/*******************************************************************************
 * Copyright (c) 2009 Martin O. J. Schmitz.
 * 
 * This file is part of the SCHMITZM library - a collection of utility 
 * classes based on Java 1.6, focusing (not only) on Java Swing 
 * and the Geotools library.
 * 
 * The SCHMITZM project is hosted at:
 * http://wald.intevation.org/projects/schmitzm/
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 3
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License (license.txt)
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 * or try this link: http://www.gnu.org/licenses/lgpl.html
 * 
 * Contributors:
 *     Martin O. J. Schmitz - initial API and implementation
 *     Stefan A. Krüger - additional utility classes
 ******************************************************************************/
package skrueger.geotools.labelsearch;

import javax.swing.SwingUtilities;

import org.apache.log4j.Logger;
import org.geotools.map.MapLayer;
import org.opengis.feature.simple.SimpleFeature;

public class SearchResultFeature implements SearchResult {
	final static private Logger LOGGER = Logger
			.getLogger(SearchResultFeature.class);

	private final SimpleFeature feature;
	private final String title;
	private final schmitzm.geotools.gui.SelectableXMapPane mapPane;
	private final String inTitle;

	private final MapLayer mapLayer;

	public SearchResultFeature(SimpleFeature feature, String title, String inTitle,
			schmitzm.geotools.gui.SelectableXMapPane mapPane, MapLayer mapLayer) {
		this.feature = feature;
		this.title = title;
		this.inTitle = inTitle;
		this.mapPane = mapPane;
		this.mapLayer = mapLayer;
	}

	@Override
	public String toString() {
		return feature.toString();
	}

	public SimpleFeature getFeature() {
		return feature;
	}

	@Override
	public String getTitle() {
		return title;
	}

	@Override
	public void open() {

		// GuiAndTools.checkThatWeAreOnEDT();
		if (!SwingUtilities.isEventDispatchThread()) {
			LOGGER.error("Not on EDT");
			throw new RuntimeException("Not on EDT!");
		}

		mapPane.zoomTo(feature);
		mapPane.refresh();

		// TODO
		// Mark the selected SimpleFeature using a spacial style.. similar to the
		// selection stuff.
		// mapLayer.getStyle().addFeatureTypeStyle( new FeatureTypeStyle());

	}

	@Override
	public String getInTitle() {
		return inTitle;
	}

}
