/*******************************************************************************
 * Copyright (c) 2009 Martin O. J. Schmitz.
 * 
 * This file is part of the SCHMITZM library - a collection of utility 
 * classes based on Java 1.6, focusing (not only) on Java Swing 
 * and the Geotools library.
 * 
 * The SCHMITZM project is hosted at:
 * http://wald.intevation.org/projects/schmitzm/
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 3
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License (license.txt)
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 * or try this link: http://www.gnu.org/licenses/lgpl.html
 * 
 * Contributors:
 *     Martin O. J. Schmitz - initial API and implementation
 *     Stefan A. Krüger - additional utility classes
 ******************************************************************************/
/** 
 Copyright 2008 Stefan Alfons Krüger 
 
 atlas-framework - This file is part of the Atlas Framework

 This library is free software; you can redistribute it and/or modify it under the terms of the GNU Lesser General Public License as published by the Free Software Foundation; either version 2.1 of the License, or (at your option) any later version.
 This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more details.
 You should have received a copy of the GNU Lesser General Public License along with this library; if not, write to the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110, USA

 Diese Bibliothek ist freie Software; Sie dürfen sie unter den Bedingungen der GNU Lesser General Public License, wie von der Free Software Foundation veröffentlicht, weiterverteilen und/oder modifizieren; entweder gemäß Version 2.1 der Lizenz oder (nach Ihrer Option) jeder späteren Version.
 Diese Bibliothek wird in der Hoffnung weiterverbreitet, daß sie nützlich sein wird, jedoch OHNE IRGENDEINE GARANTIE, auch ohne die implizierte Garantie der MARKTREIFE oder der VERWENDBARKEIT FÜR EINEN BESTIMMTEN ZWECK. Mehr Details finden Sie in der GNU Lesser General Public License.
 Sie sollten eine Kopie der GNU Lesser General Public License zusammen mit dieser Bibliothek erhalten haben; falls nicht, schreiben Sie an die Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110, USA.
 **/
package skrueger.geotools.selection;

import java.beans.PropertyChangeEvent;

/**
 * Extends the {@link PropertyChangeEvent} by maintaining the event emitter.
 * The emitter is the {@link StyledLayerSelectionModel} while the event {@link #getSource() source}
 * holds the component which causes the {@link StyledLayerSelectionModel}
 * to invoke the event (e.g. a chart, a map or a feature table). 
 * @author <a href="mailto:martin.schmitz@koeln.de">Martin Schmitz</a> (University of Bonn/Germany)
 */
public class StyledLayerSelectionEvent extends PropertyChangeEvent {
  /** Holds the {@link StyledLayerSelectionModel} which invokes the event. */
  protected  StyledLayerSelectionModel<?> emitter = null;
  
  /**
   * Creates a new event.
   * @param emitter      the {@link StyledLayerSelectionModel} which invokes the event
   * @param source       the object which is responsible for the change (e.g. map or table);
   *                     can be {@code null} if its a refresh event with no responsible
   * @param propertyName the name of the changed property
   * @param oldValue     the old property value (can be <code>null</code>)
   * @param newValue     the new property value (can be <code>null</code>)
   */
  public StyledLayerSelectionEvent(StyledLayerSelectionModel<?> emitter, Object source, String propertyName, Object oldValue, Object newValue) {
    super(source, propertyName, oldValue, newValue);
    this.emitter = emitter;
  }
  
  /** 
   * Returns the {@link StyledLayerSelectionModel} which invokes the event.
   */
  public StyledLayerSelectionModel<?> getEmitter() {
    return emitter;
  }

}
