/*******************************************************************************
 * Copyright (c) 2009 Martin O. J. Schmitz.
 * 
 * This file is part of the SCHMITZM library - a collection of utility 
 * classes based on Java 1.6, focusing (not only) on Java Swing 
 * and the Geotools library.
 * 
 * The SCHMITZM project is hosted at:
 * http://wald.intevation.org/projects/schmitzm/
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 3
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License (license.txt)
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 * or try this link: http://www.gnu.org/licenses/lgpl.html
 * 
 * Contributors:
 *     Martin O. J. Schmitz - initial API and implementation
 *     Stefan A. Krüger - additional utility classes
 ******************************************************************************/
package skrueger.geotools.selection;

import java.beans.PropertyChangeListener;

import javax.swing.ListSelectionModel;

import org.apache.log4j.Logger;

/**
 * The {@link StyledLayerSelectionModelSynchronizer} is the super class for all
 * 
 * @author mojays
 * 
 * @param <E>
 *            The concrete implementation of {@link StyledLayerSelectionModel}
 *            that this Synchronizer works on.
 */
public abstract class StyledLayerSelectionModelSynchronizer<E extends StyledLayerSelectionModel<?>>
		implements PropertyChangeListener {
	protected final Logger LOGGER = Logger.getLogger(this.getClass());

	/**
	 * Flag to avoid event circles between {@link DpLayerVectorSelectionModel}
	 * and {@link ListSelectionModel} of the feature table.
	 */
	protected boolean selectionChangeCausedByMe = false;
	/**
	 * Holds the selection model of the layer to keep synchronized with the
	 * feature table.
	 */
	protected final E layerSelModel;

	/**
	 * Allows to enable/disable the Synchronizer's functionality it.
	 */
	private volatile boolean enabled = true;

	/**
	 * Creates a new synchronizer
	 * 
	 * @param layerSelModel
	 *            layer selection model to keep synchronized with
	 */
	protected StyledLayerSelectionModelSynchronizer(E layerSelModel) {

		this.layerSelModel = layerSelModel;
	}

	/**
	 * Allows to disable this Synchronizer. Used to disable the selection
	 * functionality if no corresponding dialog is open.
	 * 
	 * @param enabled
	 *            <code>true</code> or <code>false</code>
	 */
	public void setEnabled(boolean enabled) {
		if (enabled == false && this.enabled==true) {
			LOGGER.debug("disabling the synchronizer map -> ");
		} else if (enabled == true && this.enabled==false)  {
			LOGGER.debug("enable the synchronizer map -> ");
		}
		this.enabled = enabled;
	}

	public boolean isEnabled() {
		return enabled;
	}

}
