/*******************************************************************************
 * Copyright (c) 2009 Martin O. J. Schmitz.
 * 
 * This file is part of the SCHMITZM library - a collection of utility 
 * classes based on Java 1.6, focusing (not only) on Java Swing 
 * and the Geotools library.
 * 
 * The SCHMITZM project is hosted at:
 * http://wald.intevation.org/projects/schmitzm/
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 3
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License (license.txt)
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 * or try this link: http://www.gnu.org/licenses/lgpl.html
 * 
 * Contributors:
 *     Martin O. J. Schmitz - initial API and implementation
 *     Stefan A. Krüger - additional utility classes
 ******************************************************************************/
package skrueger.i8n;

import java.awt.Component;
import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.awt.Insets;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.MouseWheelListener;
import java.util.List;
import java.util.Locale;

import javax.swing.DefaultComboBoxModel;
import javax.swing.ImageIcon;
import javax.swing.JButton;
import javax.swing.JComboBox;
import javax.swing.JDialog;
import javax.swing.JLabel;
import javax.swing.JPanel;

import org.apache.log4j.Logger;

import schmitzm.swing.SwingUtil;
import skrueger.swing.OkButton;
import skrueger.swing.TranslationEditJPanel;

/**
 * This dialog ask the user to select one of list of given languages. The dialog
 * is modal and not visible after construction.
 * 
 * @author Stefan A. Krueger
 */
public class SwitchLanguageDialog extends JDialog {
	protected Logger LOGGER = Logger.getLogger(SwitchLanguageDialog.class);

	private static final long serialVersionUID = 1L;

	private JPanel jContentPane = null;

	private JLabel jLabelFlagimage = null;

	private JPanel jPanel = null;

	private JButton jButton = null;

	private JPanel jPanel1 = null;

	private JLabel jLabel = null;

	private JComboBox jComboBox = null;

	private final List<String> languages;

	/**
	 * A dialog to select one of the available languages. If only one language
	 * is available, select it directly. Creating this object automatically
	 * makes it visible, unless there is only one language to choose from.. it
	 * that case it disposes itself autmatically.
	 */
	public SwitchLanguageDialog(final Component owner,
			final List<String> languages) {
		super(SwingUtil.getParentWindow(owner));
		this.languages = languages;

		Translation.setActiveLang(languages.get(0));

		if (languages.size() == 1) {
			LOGGER.debug("Only language '" + languages.get(0)
					+ "' is available. It has been selected automatically.");
//			dispose();
			setModal(false);
			return;
		}

		initialize();
	}

	/**
	 * This method initializes this
	 * 
	 * @return void
	 */
	private void initialize() {
		this.setContentPane(getJContentPane());

		setDefaultCloseOperation(JDialog.DO_NOTHING_ON_CLOSE);

		pack();

		SwingUtil.centerFrameOnScreenRandom(this);
		setModal(true);
		setVisible(true);
	}

	/**
	 * This method initializes jContentPane
	 * 
	 * @return javax.swing.JPanel
	 */
	private JPanel getJContentPane() {
		if (jContentPane == null) {
			final GridBagConstraints gridBagConstraints11 = new GridBagConstraints();
			gridBagConstraints11.gridx = 1;
			gridBagConstraints11.fill = GridBagConstraints.HORIZONTAL;
			gridBagConstraints11.gridy = 1;
			final GridBagConstraints gridBagConstraints3 = new GridBagConstraints();
			gridBagConstraints3.gridx = 1;
			gridBagConstraints3.fill = GridBagConstraints.HORIZONTAL;
			gridBagConstraints3.gridy = 2;
			final GridBagConstraints gridBagConstraints1 = new GridBagConstraints();
			gridBagConstraints1.gridx = 0;
			gridBagConstraints1.fill = GridBagConstraints.BOTH;
			gridBagConstraints1.gridwidth = 2;
			gridBagConstraints1.anchor = GridBagConstraints.NORTH;
			gridBagConstraints1.gridy = 0;
			jLabelFlagimage = new JLabel(new ImageIcon(
					TranslationEditJPanel.class
							.getResource("resource/flags.jpg")));
			jContentPane = new JPanel();
			jContentPane.setLayout(new GridBagLayout());
			jContentPane.add(jLabelFlagimage, gridBagConstraints1);
			jContentPane.add(getJPanel(), gridBagConstraints3);
			jContentPane.add(getJPanel1(), gridBagConstraints11);
		}
		return jContentPane;
	}

	/**
	 * This method initializes jPanel
	 * 
	 * @return javax.swing.JPanel
	 */
	private JPanel getJPanel() {
		if (jPanel == null) {
			final GridBagConstraints gridBagConstraints4 = new GridBagConstraints();
			gridBagConstraints4.gridx = 0;
			gridBagConstraints4.anchor = GridBagConstraints.EAST;
			gridBagConstraints4.weightx = 1.0;
			gridBagConstraints4.insets = new Insets(5, 5, 5, 5);
			gridBagConstraints4.gridy = 0;
			jPanel = new JPanel();
			jPanel.setLayout(new GridBagLayout());
			jPanel.add(getJButton(), gridBagConstraints4);
		}
		return jPanel;
	}

	/**
	 * This method initializes jButton
	 * 
	 * @return javax.swing.JButton
	 */
	private JButton getJButton() {
		if (jButton == null) {
			jButton = new OkButton();
			jButton.setEnabled(false);

			jButton.addActionListener(new ActionListener() {

				public void actionPerformed(ActionEvent e) {
					dispose();
				}

			});
		}
		return jButton;
	}

	/**
	 * This method initializes jPanel1
	 * 
	 * @return javax.swing.JPanel
	 */
	private JPanel getJPanel1() {
		if (jPanel1 == null) {
			final GridBagConstraints gridBagConstraints2 = new GridBagConstraints();
			gridBagConstraints2.fill = GridBagConstraints.VERTICAL;
			gridBagConstraints2.gridy = 0;
			gridBagConstraints2.weightx = 1.0;
			gridBagConstraints2.insets = new Insets(5, 5, 5, 5);
			gridBagConstraints2.anchor = GridBagConstraints.WEST;
			gridBagConstraints2.gridx = 1;
			final GridBagConstraints gridBagConstraints = new GridBagConstraints();
			gridBagConstraints.gridx = 0;
			gridBagConstraints.insets = new Insets(0, 5, 0, 0);
			gridBagConstraints.gridy = 0;
			jLabel = new JLabel();
			jLabel.setText("Select language: "); // i8n!?! Maybe replace with an
			// icon of an index finger
			jPanel1 = new JPanel();
			jPanel1.setLayout(new GridBagLayout());
			jPanel1.add(jLabel, gridBagConstraints);
			jPanel1.add(getJComboBox(), gridBagConstraints2);
		}
		return jPanel1;
	}

	/**
	 * This method initializes jComboBox
	 * 
	 * @return javax.swing.JComboBox
	 */
	private JComboBox getJComboBox() {
		if (jComboBox == null) {
			jComboBox = new JComboBox();

			jComboBox.addMouseWheelListener(new MouseWheelListener() {
				public void mouseWheelMoved(java.awt.event.MouseWheelEvent e) {

					if ((e.getWheelRotation() < 0)) {
						if (jComboBox.getSelectedIndex() < jComboBox
								.getItemCount() - 1)
							jComboBox.setSelectedIndex(jComboBox
									.getSelectedIndex() + 1);
					} else {
						if (jComboBox.getSelectedIndex() > 0)
							jComboBox.setSelectedIndex(jComboBox
									.getSelectedIndex() - 1);
					}
				}
			});

			String[] langNames = new String[languages.size() + 1];
			for (int i = 0; i < languages.size(); i++) {

				Locale locale = I8NUtil.getLocaleFor(languages.get(i));

				langNames[i] = locale.getDisplayLanguage(locale) + " / "
						+ locale.getDisplayLanguage() + " / "
						+ languages.get(i);
			}
			langNames[languages.size()] = "?";

			jComboBox.setModel(new DefaultComboBoxModel(langNames));
			jComboBox.setSelectedItem(langNames[languages.size()]);

			jComboBox.addActionListener(new ActionListener() {

				public void actionPerformed(final ActionEvent e) {
					if (jComboBox.getSelectedIndex() == languages.size()) {
						getJButton().setEnabled(false);
						return;
					}

					String l = languages.get(jComboBox.getSelectedIndex());
					try {
						Translation.setActiveLang(l);

						getJButton().setEnabled(true);
					} catch (java.lang.IllegalArgumentException ee) {
						LOGGER.warn("The language " + l + " is not valid", ee);
						getJButton().setEnabled(false);
					}

				}

			});
		}
		return jComboBox;
	}

}
