/*******************************************************************************
 * Copyright (c) 2009 Martin O. J. Schmitz.
 * 
 * This file is part of the SCHMITZM library - a collection of utility 
 * classes based on Java 1.6, focusing (not only) on Java Swing 
 * and the Geotools library.
 * 
 * The SCHMITZM project is hosted at:
 * http://wald.intevation.org/projects/schmitzm/
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 3
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License (license.txt)
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 * or try this link: http://www.gnu.org/licenses/lgpl.html
 * 
 * Contributors:
 *     Martin O. J. Schmitz - initial API and implementation
 *     Stefan A. Krüger - additional utility classes
 ******************************************************************************/
package skrueger.swing;

import java.awt.Dimension;

import javax.swing.Action;
import javax.swing.Icon;
import javax.swing.ImageIcon;
import javax.swing.JButton;

/**
 * An Ok {@link JButton} without text, but with an expressive {@link Icon} that
 * symbolizes OK
 * 
 * @author <a href="mailto:skpublic@wikisquare.de">Stefan Alfons Kr&uuml;ger</a>
 */
public class OkButton extends JButton {

	public static final Icon ICON_OK_SMALL = new ImageIcon(OkButton.class
			.getResource("small/ok.png"));

	private static final Dimension DIMENSION = new Dimension(35, 25);

	/**
	 * Creates a {@link JButton} with an icon that symbolizes OK
	 */
	public OkButton() {
		super(ICON_OK_SMALL);
		setMaximumSize(DIMENSION);
	}

	/**
	 * Creates a {@link JButton} with an icon that symbolizes OK
	 */
	public OkButton(Action a) {
		super(a);
		setIcon(ICON_OK_SMALL);
		setMaximumSize(DIMENSION);
	}
}
