package skrueger.swing.formatter;

import java.text.DecimalFormat;
import java.text.FieldPosition;

/**
 * A formatter that formats double and long byte number into a Kb, Mb or Gb
 * format.
 */

public class MbDecimalFormatter extends DecimalFormat {

	public MbDecimalFormatter() {
		super("#########0.0");
	}

	@Override
	public StringBuffer format(double number, StringBuffer result,
			FieldPosition fieldPosition) {

		String unit = "Mb";
		number /= 1024. * 1024.;
		if (number >= 512.) {
			unit = "Gb";
			number /= 1024.;
		}

		if (number >= 0.1) {
			return super.format(number, result, fieldPosition).append(unit);
		} else {
			return super.format(0.1, result, fieldPosition).append(unit)
					.insert(0, "<");
		}

	};

	@Override
	public StringBuffer format(long number_l, StringBuffer result,
			FieldPosition fieldPosition) {

		if (number_l < Double.MAX_VALUE) {
			// The number is not that big.. convert to Double and go...
			return format(Double.valueOf(number_l), result, fieldPosition);
		}

		// We have a BIG number... Rounding-errors don't count anymore.
		number_l /= 1024. * 1024.;
		String unit = "Mb";

		if (number_l >= 512.) {
			unit = "Gb";
			number_l /= 1024.;
		}

		if (number_l >= 0.1) {
			return super.format(number_l, result, fieldPosition).append(unit);
		} else {
			return super.format(0.1, result, fieldPosition).append(unit)
					.insert(0, "<");
		}

	};

}
